*
*  List the scenarios here:
   SET   T         EXPERIMENT LOOP                 / BASE, B_A_U, SCEN1, SCEN2 / ;
*
* FORECAST_YEAR in the include will be the year for which the forecast will be calculated
*(choose between 2003 (current year)and 2050)
$SETGLOBAL FORECAST_YEAR 2006

* CPI_YEAR in the include will be the year for real dollars
$SETGLOBAL CPI_YEAR 2006

* Gasoline price for FORECAST_YEAR in CPI_YEAR dollars per gallon
$SETGLOBAL PR_GASOL 1.83

* Natural gas price for FORECAST_YEAR in CPI_YEAR dollars per MMBtu
$SETGLOBAL PR_NTGAS 5.20


$ONTEXT
INDEX TO MODEL SECTIONS
*
  1. OVERALL SETTINGS FOR GAMS AND OUTPUT FILE
    1.1 CONTROLS PLACED ON OUTPUT GENERATION
    1.2 SET UP FILE FOR SOLUTION VALUES
*
  2. SET DEFINITION
    2.1 EXPLICIT SET DECLARATION
    2.2 ALIASES
*
  3. PARAMETERS AND EXOGENOUS VARIABLES
    3.1 SOCIAL ACCOUNTING MATRIX, CAPITAL COEFFICIENT MATRIX AND PARAMETERS
    3.2 PARAMETER DECLARATION
    3.3 CALCULATIONS OF PARAMETERS AND INITIAL VALUES
*
  4. VARIABLES
    4.1 VARIABLE DECLARATION
    4.2 INITIALIZATION OF VARIABLES
    4.3 REMOVING TRACE NUMBERS FOR COMPUTATIONAL PURPOSES
    4.4 SETTING COMPUTATIONALLY USEFUL BOUNDS ON VARIABLES (TO HELP THE SOLVER)
*
  5. PRE-MODEL CHECK OF PARAMETERS AND INITIAL VALUES OF VARIABLES
    5.1 PRINTING CALCULATED PARAMETERS AND EXOGENOUS VARIABLES
*
  6. EQUATIONS
    6.1 EQUATION DECLARATION
    6.2 EQUATION ASSIGNMENT
      6.2.1 HOUSEHOLDS
      6.2.2 PRODUCERS
      6.2.3 TRADE
      6.2.4 INVESTMENT
      6.2.5 LABOR SUPPLY AND MIGRATION
      6.2.6 HOUSEHOLD INCOME TAXATION
      6.2.7 GOVERNMENT
      6.2.8 MODEL CLOSURE
      6.2.9 MODEL CLOSURE USING FIXED VALUES (COMPUTATIONALLY MORE EFFICIENT THAN EQUATIONS)
*
  7. SOLVE AND OUTPUT PREPARATION
    7.1 MODEL FORMULATION
    7.2 SAVING INITIAL VALUES FOR VARIABLES
    7.3 POLICY EXPERIMENT LOOP
    7.4 PUT RESULTS INTO OUTPUT FILE
*
$OFFTEXT
*----------------------------------------------------------------
* 1. OVERALL SETTINGS FOR GAMS AND OUTPUT FILE
*----------------------------------------------------------------
* 1.1 CONTROLS PLACED ON OUTPUT GENERATION
*----------------------------------------------------------------
*
$OFFSYMLIST OFFSYMXREF
*
OPTIONS SYSOUT=OFF, SOLPRINT=OFF, LIMROW=1000, LIMCOL=0;
*
*----------------------------------------------------------------
* 1.2 SET UP FILE FOR SOLUTION VALUES
*----------------------------------------------------------------
*
  FILE RES /SCENARIO.RES/; RES.PW = 250; RES.ND = 6; RES.LW = 13;
                         RES.NW =  13; RES.LJ = 1; PUT RES;
*
*----------------------------------------------------------------
* 2. SET DEFINITION
*----------------------------------------------------------------
* 2.1 EXPLICIT SET DECLARATION
*----------------------------------------------------------------
*
SETS  Z  ALL ACCOUNTS IN SOCIAL ACCOUNTING MATRIX /
 AGRIC     Agriculture
 CATTLE    Cattle
 DAIRY     Dairy
 FOREST    Forestry
 OILGAS    Petroleum and Natural Gas Extraction
 OTHPRI    Mining
 DISTEL    Electrical Power Generation and Distribution
 DSTGAS    Natural Gas Distribution
 DSTOTH    Water Distribution and Sewage Treatment
 CONRES    Residential Construction
 CONNON    Nonresidential Construction
 CONSTR    Street and Bridge Construction
 CONUTL    Utility Infrastructure Construction
 CONOTH    Other Construction-related Industry
 FDMFG     Food Manufacturing
 FDPROC    Food Processing
 FDOTH     Other Food Related Industry
 BEVTOB    Beverage and Tobacco Products
 TEXLTH    Textile and Leather Manufacturing
 APPREL    Apparel Manufacturing
 WOOD      Wood Products Manufacturing
 PLPMLL    Pulp and Paper Mills
 PAPER     Paper Products Manufacturing
 PRINT     Printing
 OILREF    Oil Refineries
 INDGAS    Industrial Gas
 CHMDRG    Chemical and Drugs Manufacture
 CHMBAS     Basic Chemical Manufacture
 CHMSPS     Soaps and Detergents Manufacture
 CHMOTH     Other Chemical Products Manufacture
 PLASTC     Plastics Manufacture
 GLASS      Glass Products Manufacture
 CEMENT    Cement
 CONCRT    Concrete
 SCAOTH    China and Clay Products
 PRIMTL    Primary Metals
 ALUM      Aluminum
 MTLFAB    Metal Fabrication
 MACHIN    Machinery Manufacture
 RFARCN    Refrigeration and Air Conditioning
 CMPMFG    Computer Manufacture
 CMPCMM    Communications Equipment Manufacture
 CMPRTS    Electronic Components Manufacture
 CMPINS    Electronic Instruments Manufacture
 CMPMED    Electronic Recording Media Manufacture
 ELCTRC    Electrical Equipment Manufacture
 AUTOMF    Automobile Manufacturing
 VEHMFG    Other Vehicle Manufacture
 VEHBDY    Motor Vehicle Body Manufacture
 VEHPRT    Motor Vehicle Parts Manufacture
 VEHSHP    Ship Building and Repair
 VEHOTH    Other Vehicle Manufacture
 VEHAER    Aerospace Manufacture
 FURN      Furniture
 LABDNT    Laboratory and Dental Equipment
 MSCMFG    Miscellaneous Manufacturing
 VEHSRV    Vehicle Services
 WHLDUR    Wholesale Durable Goods
 WHLNON    Wholesale Non Durable Goods
 WHLGAS    Wholesale Gas
 WHLAGN    Wholesale Trade
 TRANSP    Transportation
 AIRTNS    Air Transportation
 RRTNS     Railroad Transportation
 WATTNS    Waterway Transportation
 TRKTNS    Truck Transportation
 PUBTNS    Public Transportation
 OTHTNS    Other Transportation
 VEHTNS    Vehicle Transportation
 RETVEH    Retail Vehicles and Parts
 RETFRN    Retail Furniture
 RETELC    Retail Electronics and Appliances
 RETBLD    Retail Building Materials
 RETFD     Retail Food and Beverage
 RETDRG    Retail Health and Personal Care
 RETGAS    Retail Gasoline Stations
 RETAPP    Retail Clothing and Accessories
 RETSPT    Retail Sporting Goods and Books and Music
 RETGEN    Retail General Merchandise
 RETMSC    Retail Miscellaneous
 RETNON    Retail Nonstore
 INFOPC    Motion Picture Industry
 INFOTH    Other Broadcasting and Recording Industry
 INFOTL    Telecommunications
 INFCOM    Internet and Information Services
 FINSEC    Financial Securities
 FINSUR    Insurance
 FIBNKS    Banking
 FIREAL    Real Estate
 FINOTH    Other Financial
 PROLEG    Legal Services
 PROACC    Accounting
 PROARC    Architecture
 PRODES    Design
 PROCOM    Computer Related Services
 PROCNS    Consulting
 PRORES    Research
 PROADV    Advertising
 PROOTH    Other Professional Services
 BUSSRV    Business Services
 ADMTMP    Temporary Administrative Services
 ADMSEC    Security Services
 ADMBLD    Building Maintenance
 ADMOTH    Other Administrative Services
 WSTSRV    Waste Management
 LNDFIL    Landfills
 EDUC      Education
 MEDAMB    Medical Services
 MEDHSP    Hospitals
 MEDNRS    Nursing
 MEDSA     Day Care
 RECENT    Recreation and Entertainment
 RECAMS    Amusement Parks
 ACCHOT    Hotels
 ACCRST    Full Service Restaurants
 ACCFST    Fast Food
 ACCSPC    Caters and Mobile Food Services
 ACCBRS    Drinking Establishments
 PERSRV    Personal Services
*
 LABOR   FACTOR     FACTOR LABOR
 CAPIT   FACTOR     FACTOR ALL OTHER FACTORS COMBINED AS CAPITAL
 CFOOD   COMMODITY  FOOD AND BEVERAGE
 CHOME   COMMODITY  SHELTER
 CFUEL   COMMODITY  FUEL AND UTILITIES
 CFURN   COMMODITY  HOUSEHOLD FURNISHING AND OPERATION
 CCLTH   COMMODITY  APPAREL AND ITS UPKEEP
 CTRNS   COMMODITY  TRANSPORTATION
 CMEDS   COMMODITY  MEDICAL CARE
 CAMUS   COMMODITY  ENTERTAINMENT
 COTHR   COMMODITY  OTHER GOODS AND SERVICES
 HOUS0   HOUSEHOLD  0.0 PERCENT MARGINAL CA PIT
 HOUS1   HOUSEHOLD  1.0 PERCENT MARGINAL CA PIT
 HOUS2   HOUSEHOLD  2.0 PERCENT MARGINAL CA PIT
 HOUS4   HOUSEHOLD  4.0 PERCENT MARGINAL CA PIT
 HOUS6   HOUSEHOLD  6.0 PERCENT MARGINAL CA PIT
 HOUS8   HOUSEHOLD  8.0 PERCENT MARGINAL CA PIT
 HOUS9   HOUSEHOLD  9.3 PERCENT MARGINAL CA PIT UNDER 200K
 HOUSH   HOUSEHOLD  9.3 PERCENT MARGINAL CA PIT OVER 200K
 INVES   INVESTMENT
 FTSOC   GOVERNMENT FEDERAL    TAX      SOCIAL SECURITY
 FTPIT   GOVERNMENT FEDERAL    TAX      PERSONAL INCOME TAX
 FTPRO   GOVERNMENT FEDERAL    TAX      PROFITS
 FTDUT   GOVERNMENT FEDERAL    TAX      DUTY
 FTMSC   GOVERNMENT FEDERAL    TAX      MISCELLANEOUS
 CTHHS   GOVERNMENT CALIFORNIA TAX      VARIOUS HOUSEHOLD TAXES
 CTBOZ   GOVERNMENT CALIFORNIA TAX      ALCOHOL TAXES
 CTCIG   GOVERNMENT CALIFORNIA TAX      CIGARETTE TAXES
 CTHOR   GOVERNMENT CALIFORNIA TAX      HORSE RACING
 CTEST   GOVERNMENT CALIFORNIA TAX      ESTATE TAXES
 CTTRL   GOVERNMENT CALIFORNIA TAX      TRAILER FEES
 CTLIC   GOVERNMENT CALIFORNIA TAX      MOTOR VEHICLE LICENSE FEES
 CTDIE   GOVERNMENT CALIFORNIA TAX      DIESEL FUEL TAXES
 CTREG   GOVERNMENT CALIFORNIA TAX      MOTOR VEHICLE REGISTRATION FEES
 CTMSC   GOVERNMENT CALIFORNIA TAX      MISCELLANEOUS
 CTINS   GOVERNMENT CALIFORNIA TAX      INSURANCE GROSS PREMIUM TAX
 CTGAS   GOVERNMENT CALIFORNIA TAX      GASOLINE FUEL TAXES
 CTSAU   GOVERNMENT CALIFORNIA TAX      SALES AND USE TAXES
 CTBAC   GOVERNMENT CALIFORNIA TAX      BANK AND CORPORATION TAX
 CTLAB   GOVERNMENT CALIFORNIA TAX      LABOR TAXES   UI AND WORKERS COMP
 CTPIT   GOVERNMENT CALIFORNIA TAX      PERSONAL INCOME TAX
 CTRGU   GOVERNMENT CALIFORNIA TAX      REGULATORY LICENSES AND FEES
 CTSVC   GOVERNMENT CALIFORNIA TAX      SERVICES TO THE PUBLIC
 CTPAM   GOVERNMENT CALIFORNIA TAX      USE OF PROPERTY AND MONEY
 CGENF   GOVERNMENT CALIFORNIA GENERAL FUND
 LTPRP   GOVERNMENT LOCAL      TAX      PROPERTY
 LTSAU   GOVERNMENT LOCAL      TAX      SALES AND USE
 LTFMS   GOVERNMENT LOCAL      TAX      MISCELLANEOUS ON FIRMS
 LTHHS   GOVERNMENT LOCAL      TAX      MISCELLANEOUS ON HOUSEHOLDS
 LTMSC   GOVERNMENT LOCAL      TAX      MISCELLANEOUS ON FIRMS AND HOUSEHOLDS
 FSDEF   GOVERNMENT FEDERAL    SPENDING DEFENSE
 FSNON   GOVERNMENT FEDERAL    SPENDING NON DEFENSE
 CSTRA   GOVERNMENT CALIFORNIA SPENDING TRANSPORTATION
 CSCOR   GOVERNMENT CALIFORNIA SPENDING CORRECTIONS
 CSK14   GOVERNMENT CALIFORNIA SPENDING K TO 14 EDUCATION
 CSUNI   GOVERNMENT CALIFORNIA SPENDING UNIVERSITIES
 CSWEL   GOVERNMENT CALIFORNIA SPENDING WELFARE
 CSHTH   GOVERNMENT CALIFORNIA SPENDING HEALTH
 CSOTH   GOVERNMENT CALIFORNIA SPENDING OTHER
 LSTRA   GOVERNMENT LOCAL      SPENDING TRANSPORTATION
 LSCOR   GOVERNMENT LOCAL      SPENDING CORRECTIONS
 LSK14   GOVERNMENT LOCAL      SPENDING K TO 14 EDUCATION
 LSWEL   GOVERNMENT LOCAL      SPENDING WELFARE
 LSHTH   GOVERNMENT LOCAL      SPENDING HEALTH
 LSOTH   GOVERNMENT LOCAL      SPENDING OTHER
 ROW     REST OF WORLD /
*
      C(Z)      COMPOSITE COMMODITIES    / CFOOD, CHOME, CFUEL, CFURN, CCLTH, CTRNS, CMEDS, CAMUS, COTHR /
*
      F(Z)      FACTORS                  / LABOR, CAPIT /
*
      G(Z)      GOVERNMENTS              / FTSOC, FTPIT, FTPRO, FTDUT, FTMSC, CTHHS, CTBOZ, CTCIG, CTHOR, CTEST,
                                           CTTRL, CTLIC, CTDIE, CTREG, CTMSC, CTINS, CTGAS, CTSAU, CTBAC, CTLAB,
                                           CTPIT, CTRGU, CTSVC, CTPAM, CGENF, LTPRP, LTSAU, LTFMS, LTHHS, LTMSC,
                                           FSDEF, FSNON, CSTRA, CSCOR, CSK14, CSUNI, CSWEL, CSHTH, CSOTH, LSTRA,
                                           LSCOR, LSK14, LSWEL, LSHTH, LSOTH /
*
      GC(G)     CALIFORNIA SPENDING      / CSTRA, CSCOR, CSK14, CSUNI, CSWEL, CSHTH, CSOTH /
*
      GED(G)    EDUCATION UNITS          / CSK14, CSUNI, LSK14 /
*
      GL(G)     LOCAL GOVERNMENT UNITS   / LSTRA, LSCOR, LSK14, LSWEL, LSHTH, LSOTH /
*
      GN(G)     ENDOGENOUS GOVERNMENTS   / CSTRA, CSCOR, CSK14, CSUNI, CSWEL, CSHTH, CSOTH,
                                           LSTRA, LSCOR, LSK14,        LSWEL, LSHTH, LSOTH /
*
      GX(G)     EXOGENOUS GOVERNMENTS    / FSDEF, FSNON /
*
      GS(G)     SALES OR EXCISE TAXES    / FTMSC, CTBOZ, CTCIG, CTHOR, CTTRL, CTLIC, CTDIE, CTREG, CTMSC, CTINS,
                                           CTGAS, CTSAU, CTRGU, CTPAM, LTPRP, LTSAU, LTFMS, LTMSC /
*
      GF(G)     FACTOR TAXES             / FTSOC, FTPRO, CTBAC, CTLAB /
*
      GI(G)     INCOME TAX UNITS         / FTPIT, CTPIT, LTPRP /
      GH(G)     HOUSEHOLD TAX UNITS      / FTMSC, CTHHS, CTEST, CTRGU, CTSVC, LTHHS, LTMSC /
*
      GNS(G)    INFRASTRUCTURE GOV'TS    / CSTRA, CSCOR, CSWEL, CSHTH, CSOTH, LSTRA, LSCOR, LSHTH, LSOTH /
***removed lswel from GNS.
*
      GW(G)     TRANSFER PAYMENTS        / FTSOC, FSNON, CTLAB, LSWEL, LSHTH /
*
      GSF(G)     CA SPECIAL FUNDS UNITS   / CTHHS, CTBOZ, CTCIG, CTHOR, CTLIC, CTDIE, CTREG, CTMSC, CTINS, CTGAS,
                                           CTSAU, CTRGU, CTSVC, CTPAM /
*
      GT(G)     TAX UNITS                / FTSOC, FTPIT, FTPRO, FTDUT, FTMSC, CTHHS, CTBOZ, CTCIG, CTHOR, CTEST,
                                           CTTRL, CTLIC, CTDIE, CTREG, CTMSC, CTINS, CTGAS, CTSAU, CTBAC, CTLAB,
                                           CTPIT, CTRGU, CTSVC, CTPAM, LTPRP, LTSAU, LTFMS, LTHHS, LTMSC /
*
      H(Z)      HOUSEHOLDS               / HOUS0, HOUS1, HOUS2, HOUS4, HOUS6, HOUS8, HOUS9, HOUSH /
*
      I(Z)      INDUSTRY SECTORS
                    /
                    AGRIC,    CATTLE,   DAIRY,    FOREST,   OILGAS,   OTHPRI,   DISTEL,   DSTGAS,
                    DSTOTH,   CONRES,   CONNON,   CONSTR,   CONUTL,   CONOTH,   FDMFG,    FDPROC,
                    FDOTH,    BEVTOB,   TEXLTH,   APPREL,   WOOD,     PLPMLL,   PAPER,    PRINT,    OILREF,
                    INDGAS,   CHMDRG,   CHMBAS,   CHMSPS,   CHMOTH,   PLASTC,   GLASS,    CEMENT,
                    CONCRT,   SCAOTH,   PRIMTL,   ALUM,     MTLFAB,   MACHIN,   RFARCN,   CMPMFG,   CMPCMM,
                    CMPRTS,   CMPINS,   CMPMED,   ELCTRC,   AUTOMF,   VEHMFG,   VEHBDY,   VEHPRT,
                    VEHSHP,   VEHOTH,   VEHAER,   FURN,     LABDNT,   MSCMFG,   VEHSRV,   WHLDUR,   WHLNON,
                    WHLGAS,   WHLAGN,   TRANSP,   AIRTNS,   RRTNS,    WATTNS,   TRKTNS,   PUBTNS,   OTHTNS,
                    VEHTNS,   RETVEH,   RETFRN,   RETELC,   RETBLD,   RETFD,    RETDRG,   RETGAS,
                    RETAPP,   RETSPT,   RETGEN,   RETMSC,   RETNON,   INFOPC,   INFOTH,   INFOTL,
                    INFCOM,   FINSEC,   FINSUR,   FIBNKS,   FIREAL,   FINOTH,   PROLEG,   PROACC,
                    PROARC,   PRODES,   PROCOM,   PROCNS,   PRORES,   PROADV,   PROOTH,   BUSSRV,
                    ADMTMP,   ADMSEC,   ADMBLD,   ADMOTH,   WSTSRV,   LNDFIL,   EDUC,     MEDAMB,   MEDHSP,
                    MEDNRS,   MEDSA,    RECENT,   RECAMS,   ACCHOT,   ACCRST,   ACCFST,   ACCSPC,
                    ACCBRS,   PERSRV
                 /

    COM(I)    COMMERCIAL SECTORS
                / ACCBRS, ACCFST, ACCHOT, ACCRST, ACCSPC, ADMBLD, ADMOTH, ADMSEC, ADMTMP,
                  BUSSRV, DISTEL, DSTGAS, DSTOTH, EDUC, FIBNKS, FINOTH, FINSEC, FINSUR, FIREAL,
                  INFCOM, INFOPC, INFOTH, INFOTL, LNDFIL, MEDAMB, MEDHSP, MEDNRS, MEDSA,
                  PERSRV, PROACC, PROADV, PROARC, PROCNS, PROCOM, PRODES, PROLEG, PROOTH,
                  PRORES, RECAMS, RECENT, RETAPP, RETBLD, RETDRG, RETELC, RETFD, RETFRN,
                  RETGAS, RETGEN, RETMSC, RETNON, RETSPT, RETVEH, VEHSRV, WHLAGN, WHLDUR,
                  WHLGAS, WHLNON, WSTSRV /

    EI(I)     ENERGY INTENSIVE INDUSTRY
                / ALUM, CEMENT, CHMBAS, CHMDRG, CHMOTH, CHMSPS, CONCRT, GLASS, INDGAS,
                  OILGAS, OILREF, OTHPRI, PAPER, PLASTC, PLPMLL, PRIMTL, SCAOTH /

    NE(I)    NON-ENERGY INTENSIVE INDUSTRY
                / AGRIC, APPREL, AUTOMF, BEVTOB, CATTLE, CMPCMM, CMPINS,
                  CMPMED, CMPMFG, CMPRTS, CONNON, CONOTH, CONRES, CONSTR,
                  CONUTL, DAIRY, ELCTRC, FDMFG, FDOTH, FDPROC, FOREST, FURN,
                  LABDNT, MACHIN, MSCMFG, MTLFAB, PRINT, RFARCN, TEXLTH, VEHAER,
                  VEHBDY, VEHMFG, VEHOTH, VEHPRT, VEHSHP, WOOD, AIRTNS, OTHTNS,
                  PUBTNS, RRTNS, TRANSP, TRKTNS, VEHTNS, WATTNS  /

    TI(I)     PERMIT SECTORS / DAIRY,   FOREST,  OILGAS,   DISTEL,   DSTGAS,    DSTOTH,  OILREF,
                               CEMENT,  LNDFIL /
    TIC(I)    NON PERMIT SECTORS

    K         NUMBER OF ALTERNATIVES  /1*3/
*
*
      R1H       REPORT 1 FOR SCALARS     / FORYR  'FORECAST YEAR                   ',
                                           CPIYR  'CPI YEAR                        ',
                                           OUT_N  'NOMINAL CA OUTPUT ($BILLION)    ',
                                           OUT_R  'REAL CA OUTPUT ($BILLION)       ',
                                           GSP    'GROSS STATE PRODUCTS ($BILLION) ',
                                           GSP_R  'REAL GSP ($BILLION)             ',
                                           SPI    'CALIFORNIA PERSONAL INCOME      ',
                                           SPI_R  'REAL SPI ($BILLION)             ',
                                           SPICAP 'SPI PER CAPITA ($THOUSANDS)     ',
                                           LD     'LABOR DEMAND (MILLIONS)         ',
                                           CRBCP  'CARBON CAP (MMT CO2)            ',
                                           CRBRT  'CARBON PRICE ($ PER TON CO2E)   ',
                                           CRBRV  'CARBON TAX RECYCLED ($BILLION)  ',
                                           CRBTX  'CARBON TAX COLLECTED  ($BILLION)',
                                           IMPRT  'TOTAL IMPORTS ($BILLION)        ',
                                           EXPRT  'TOTAL EXPORTS ($BILLION)        ',
                                           WRKRS  'WORKING FAMILIES (MILLIONS)     ',
                                           GN     'GROSS INVESTMENT                ',
                                           PINV   'NET PRIVATE INVEST ($MILLION)   ',
                                           POP    'POPULATION (MILLION FAMILIES)   ',
                                           W      'WAGE INDEX (BASE = 100)         ',
                                           R      'RETURN TO CAPITAL INDEX         ',
                                           KD     'CAPITAL STOCK ($100 BILLION)    ',
                                           CPI    'CONSUMER PRICE INDEX (BASE=1)   ',
                                           BAC    'BANK AND CORP TAX REVENUE       ',
                                           PIT    'PERSONAL INCOME TAX REVENUE     ',
                                           SAU    'SALES AND USE TAX REVENUE       ',
                                           GFREV  'GENERAL FUND REVENUE            ',
                                           SFREV  'SPECIAL FUND REVENUE            ',
                                           SUBSS  'TOTAL SUBSIDIES                 ',
                                           STATIC 'STATIC REVENUE ESTIMATE         ',
                                           DGF    'CHANGE IN GENERAL FUND          ',
                                           DSF    'CHANGE IN SPECIAL FUND          ',
                                           DDRE   'DOLLARS DYNAMIC REVENUE EFFECT  ',
                                           PDRE   'PERCENT DYNAMIC REVENUE EFFECT  ',
                                           GFSAV  'GENERAL FUND BALANCE            ',
                                           MIC    'MANUFACTURERS INVESTMENT CREDIT ',
                                           PROP98 'PROP 98 TRANSFER TO K14 EDUC    '/
*                                           SLACK  'The Slack variable in IGT       '/
*
      R2H       REPORT 2 FOR STATUS      / M-STAT, S-STAT /
*
      R3H       REPORT 3 FOR SECTORS     / IGT    'TRANSFERS FROM GF  ',
                                           GOVS   'GOVT SAVINGS       ',
                                           Y      'HH INCOME. ($TH)   '/
      R4H       REPORT 4 FOR INDUSTRIES   / INTERMED       'AVG% INCR. INTRMDS DUE TO REGS  ',
                                            INTRMD1        '$ INCR. SPENDING ON INTERMEDS   ',
                                            DS             'OUTPUT ($BILLION)  ',
                                            D1DS           'CHANGE OUTPUT                   ',
                                            D2DS           '% CHANGE OUTPUT                 ',
                                            TAX            'IMPLICIT TAX RATE TAUQ          ',
                                            INDUSTD        'INDUSTRY DEMAND                 ',
                                            HOUSED         'HOUSEHOLD DEMAND                ',
                                            GOVTD          'GOVT DEMAND                     ',
                                            FDK            'CAPITAL ($100 BILLION)          ',
                                            D1FDK          'CHANGE CAPITAL                  ',
                                            D2FDK          '% CHANGE CAPITAL                ',
                                            FDL            'JOBS (MILLIONS)    ',
                                            D1FDL          'CHANGE JOBS                     ',
                                            D2FDL          '% CHANGE JOBS                   ',
                                            P              'PRICE (BASE=1)     ',
                                            D1P            'CHANGE PRICE                    ',
                                            D2P            '% CHANGE PRICE                  ',
                                            PVA            'PRICE VALUE ADDED  ',
                                            D1PVA          'CHANGE PVA                      ',
                                            D2PVA          '%CHANGE PVA                     ',
                                            VA             'VALUE ADDED ($B)   ',
                                            D1VA           'CHANGE PVA                      ',
                                            D2VA           '%CHANGE PVA                     ',
                                            PD             'DOMESTIC PRICE                  ',
                                            M              'IMPORTS ($BILLION) ',
                                            D1M            'CHANGE IMPORTS                  ',
                                            D2M            '% CHANGE IMPORTS                ',
                                            X              'EXPORTS ($BILLION) ',
                                            D1X            'CHANGE EXPORTS                  ',
                                            D2X            '% CHANGE EXPORTS                ',
                                            CARBPR         'CO2E PRODUCED (MMT)',
                                            CARBIMP        'CO2E IMPORTED (MMT)',
                                            CO2ELC         'ELCTR CO2 COST ($B)',
                                            RRL            'LABOR RENTAL RATE (BASE=100)    ',
                                            D1RRL          'CHANGE LABOR RENTAL RATE        ',
                                            D2RRL          '%CHANGE LABOR RENTAL RATE       ',
                                            RRK            'CAPITAL RENTAL RATE (BASE=100)  ',
                                            D1RRK          'CNANGE CAPITAL RENTAL RATE      ',
                                            D2RRK          '% CHANGE CAPITAL RENTAL RATE    ',
                                            FTAXK          'K FACTOR TAX                    ',
                                            FTAXL          'L FACTOR TAX                    ',
                                            KRETURN        'PRE-TAX K-RETURN                ',
                                            LRETURN        'PRE-TAX L-RETURN                ',
                                            CH0A           'SPENDING PORTION OF CH0(I)      ',
                                            CH0B           'TAX PORTION OF CH0(I)           '/
*
*
R4LH(R4H) SMALL REPORT 4 FOR INDUSTRIES   / DS             'OUTPUT ($BILLION)               ',
*                                            D1DS           'CHANGE OUTPUT                   ',
*                                            D2DS           '% CHANGE OUTPUT                 ',
                                            P              'PRICE (BASE=1)                  ',
*                                            D1P            'CHANGE PRICE                    ',
*                                            D2P            '% CHANGE PRICE                  ',
*                                           PVA            'PRICE (BASE=1)                  ',
*                                            D1PVA          'CHANGE PRICE                    ',
*                                            D2PVA          '% CHANGE PRICE                  ',
                                            VA             'VALUE ADDED ($B)                 ',
*                                            D1PVA          'CHANGE PRICE                    ',
*                                            D2PVA          '% CHANGE PRICE                  ',
                                            M              'IMPORTS ($BILLION)              ',
*                                            D1M            'CHANGE IMPORTS                  ',
*                                            D2M            '% CHANGE IMPORTS                ',
                                            X              'EXPORTS ($BILLION)              ',
*                                            D1X            'CHANGE EXPORTS                  ',
*                                            D2X            '% CHANGE EXPORTS                ',
                                            FDL            'JOBS (MILLIONS)                 ',
*                                            D1FDL          'CHANGE JOBS                     ',
*                                            D2FDL          '% CHANGE JOBS'
                                            CARBPR         'CO2E PRODUCED (MMT)',
                                            CARBIMP        'CO2E IMPORTED (MMT)',
                                            CO2ELC         'ELCTR CO2 COST ($B)'
/
*
      MS        LABELS FOR MODEL STATUS  / 01 ' OPTIMAL_GLOB',
                                           02 ' OPTIMAL_LOCL',
                                           03 '    UNBOUNDED',
                                           04 ' INFES_GLOBAL',
                                           05 ' INFES__LOCAL',
                                           06 ' INTER_INFEAS',
                                           07 ' INTER_NON-OP',
                                           08 ' INTEG__SOLVE',
                                           09 ' INTER_NONINT',
                                           10 ' INTEG__INFES',
                                           11 '       UNUSED',
                                           12 ' ERROR_UNKNWN',
                                           13 ' ERROR_NOSOLN'/
*
      SS        LABELS FOR SOLVER STATUS / 01 '      OPTIMAL',
                                           02 '   ITERATIONS',
                                           03 '    RESOURCES',
                                           04 ' TERM__SOLVER',
                                           05 ' VALERR_LIMIT',
                                           06 '      UNKNOWN',
                                           07 '     NOT_USED',
                                           08 ' ERROR_PREPRO',
                                           09 ' ERROR__SETUP',
                                           10 ' ERROR_SOLVER',
                                           11 ' ERROR_INTERN',
                                           12 ' ERROR_POSTPR',
                                           13 ' ERROR_SYSTEM'/;
*----------------------------------------------------------------
* 2.2 ALIASES
*----------------------------------------------------------------
*
  ALIAS (I,J), (I,I1), (Z,Z1), (F,F1), (G,G1), (GI,GI1), (GS,GS1), (H,H1), (C,C1), (T,T1), (GC,GC1);
*
*----------------------------------------------------------------
* 3. PARAMETERS AND EXOGENOUS VARIABLES
*----------------------------------------------------------------
* 3.1 SOCIAL ACCOUNTING MATRIX, CAPITAL COEFFICIENT MATRIX AND PARAMETERS
*----------------------------------------------------------------
*
PARAMETER SAM(Z,Z1);
*EOM SAM120.PRN not necessary if importing the SAM through the excel file as below
$INCLUDE SAM2003.PRN
$INCLUDE CCM2003.PRN
$INCLUDE MSC2003.PRN
*
*EOM the following four line converts the excel file SAM120 into a GDX file
*which is then imported into DRAM and loaded to parameter sam(z,z1)
*$call gdxxrw.exe SAM120.xls par=sam rng=SAM120!A1:GD186
*$gdxin SAM120.gdx
*$load sam
*$gdxin


*
***pb ctmsc has source and sink as cgenf.  Net them.
SAM('cgenf','ctmsc') =  SAM('cgenf','ctmsc')- SAM('ctmsc','cgenf') ;
SAM('ctmsc','cgenf') = 0;
SAM('cgenf','ctins') =  SAM('cgenf','ctins')- SAM('ctins','cgenf') ;
SAM('ctins','cgenf') = 0;
SAM('cgenf','ctsau') =  SAM('cgenf','ctsau')- SAM('ctsau','cgenf') ;
SAM('ctsau','cgenf') = 0;
***pb  include additional 2-way trade for sectors with duty and no trade
set i2way(z) /DSTGAS,    CONSTR,    INDGAS  /  ;
sam('row',i2way) = 50*sam('ftdut',i2way);
sam(i2way,'row') = sam(i2way,'row') + 50*sam('ftdut',i2way);


**
*
*----------------------------------------------------------------
* 3.2 PARAMETER DECLARATION
*----------------------------------------------------------------
*
  SCALARS
*
  ADA           DOF     CHANGE IN AVERAGE DAILY ATTENDANCE  / 1.00 /
  DEPR          DOF     DEPRECIATION RATE;
*
  PARAMETERS
*
* PARAMETERS CALCULATED FROM SOCIAL ACCOUNTING MATRIX DATA
*
  A(Z,Z1)       IMPLAN  INPUT OUTPUT COEFFICIENTS
  AD(Z,Z1)      IMPLAN  DOMESTIC INPUT OUTPUT COEFFICIENTS
  AG(Z,G)       IMPLAN  GOVERNMENT SPENDING SHARES OF NET INCOME
  ALPHA(F,I)    IMPLAN  FACTOR SHARE EXPONENTS IN PRODUCTION FUNCTION
  ALPHA0(C,H)   DOF     CONSTANT IN LA-AIDS CONSUMPTION FUNCTION
  ALPHACG(I,G)  DOF     GOVERNMENT CONSUMPTION SHARES OF GOODS
  ALPHAFG(F,G)  DOF     GOVERNMENT SHARES OF FACTOR RENTALS
  FITC(F,G)     DOF     ALLOCATION OF ITC TO FACTORS
  IGTD(G,G1)    DOF     TYPES OF INTER GOVERNMENTAL TRANSFERS
  SIGMAH(H)     DOF     AVERAGE PROPENSITY TO SAVE
  TAUF(G,F,Z)   DOF     FACTOR TAXES
  TAUFX(G,F,Z)  DOF     EXPERIMENTAL FACTOR TAXES
  TAUFH(G,F)    DOF     EMPLOYEE PORTION OF FACTOR TAXES
  TAUH(G,H)     DOF     HOUSEHOLD TAXES OTHER THAN PIT
  TAUM(G,I)     DOF     IMPORT DUTY RATES
  TAUQ(G,I)     DOF     INITIAL SALES TAX RATES
  TAUQX(G,I)    DOF     EXPERIMENTAL SALES TAX RATES
  TAXS(G,G1)    DOF     TAX DESTINATION SHARES
  KAPPA(GNS)    DOF     POLICY WEIGHTS OF GOV'T SPENDING FOR INSFRASTRUCTURE SCALE VARIABLE
  TEST(T)       DOF     EXPERIMENT PARAMETER
*
* ELASTICITIES AND TAX PARAMETERS
*
  ETAE(I)       UCB     EXPORT ELASTICITIES WITH RESPECT TO DOMESTIC PRICE
  ETAGS(I)      UCB     PRODUCTION ELASTICITIES WITH RESPECT TO INFRASTRUCTURE SPENDING
  ETAED(H)      DOF     SENSIVITIY OF MIGRATION TO PUBLIC EDUCATION SPENDING
  ETAI(I)       UCB     INVESTMENT SUPPLY ELASTICITY
  ETAM(I)       UCB     IMPORT ELASTICITIES WITH RESPECT TO DOMESTIC PRICE
  ETARA(H)      UCB     L SUPPLY ELASTICITY WITH RESPECT TO AVERAGE WAGE
  ETAPIT(H)     UCB     L SUPPLY ELASTICITY WITH RESPECT TO TAXES
  ETAYD(H)      UCB     RESPONSIVENESS OF INMIGRATION TO AFTER TAX EARNINGS
  ETAU(H)       UCB     RESPONSIVENESS OF INMIGRATION TO UNEMPLOYMENT
  ETATP(H)      UCB     HOUSEHOLD RESPONSE TO TRANSFER PAYMENTS
  ITCX(Z,Z1)    DOF     INVESTMENT TAX CREDIT SHARE ALLOWED
  JOBCOR        CALC    CORRECTION FACTOR BETWEEN HOUSEHOLDS AND JOBS
  MIGRFACTOR    CALC    FRACTION OF BASE POPULATION INVOLVED IN MIGRATION
  MTR(G,H)      DOF     MARGINAL TAX RATES
  NRPG(H)       UCB     NATURAL RATE OF POPULATION GROWTH
  PHI(I,C)      DOF     SHARES OF CONSUMPTION COMMODITIES
  SIGMA(I)      UCB     ELASTICITY OF FACTOR SUBSTITUTION
  TAXBASE(G,H)  DOF     BASE TAX AMOUNTS
  TAXBM(G,H)    DOF     TAX BRACKET MINIMUM
  TAXCVC(G,H)   DOF     TAX CONSTANT TO CORRECT TO OBSERVED TAXES
  TAXOD(G,H)    DOF     TAX OTHER DEDUCTIONS PER RETURN
  TAXPI(G,H)    DOF     TAX PERCENT ITEMIZING
  TAXSD(G,H)    DOF     TAX STANDARD DEDUCTIONS PER RETURN
*LINGYUN definite new parameter in order to fix YEQ
  CAPFOR(F)             CAPIT PAYMENT FOR FORIENGER
* ARRAYS BUILT TO REPORT RESULTS TO SEPARATE FILE
*
  R1(R1H,T)     REPORT  SCALAR VARIABLES
  R2(R2H,T)     REPORT  SOLVER AND MODEL STATUS VALUES
  R3(R3H,Z,T)   REPORT  SECTORAL VARIABLES
  R4(R4H,I,T)   REPORT  ECONOMIC VARIABLES FOR INDUSTRIAL SOURCES
*
* INITIAL VALUES OF ENDOGENOUS VARIABLES
*
  AGI0(H)       DOF     NOMINAL PER HOUSEHOLD ADJUSTED GROSS INCOME FOR PIT PURPOSES
  CARBON0(I)    CALC    REAL    CARBON DIOXIDE EMISSIONS
  CG0(I,G)      DOF     REAL    GOVERNMENT CONSUMPTION
  CH0(I)        IMPLAN  REAL    PRIVATE CONSUMPTION
  CN0(I)        IMPLAN  REAL    INVESTMENT BY SECTOR OF SOURCE
  CS0(C,H)      DOF     SHARE   HOUSEHOLD CONSUMPTION SHARES
  CPI0(H)       CALC    PRICE   CONSUMER PRICE INDICES
  CX0(I)        IMPLAN  REAL    EXPORT CONSUMPTION
  DD0(Z)        CALC    REAL    DOMESTIC DEMAND
  DS0(Z)        CALC    REAL    DOMESTIC SUPPLY QUANTITIES
  E0(I)         CALC    REAL    INFRASTRUCTURE SCALE VARIABLE FOR PRODUCTION FUNCTIONS
  FD0(F,Z)      IMPLAN  REAL    FACTOR DEMAND
  GST0          CALC    REAL    TOTAL GOVERNMENT SPENDING INCLUDING FACTOR RENTALS
  GSED0         CALC    REAL    TOTAL STATE AND LOCAL EDUCATION SPENDING
  HH0(H)        DOF     HHDS    NUMBER OF HOUSEHOLDS
  HN0(H)        DOF     HHDS    NUMBER OF NONWORKING HOUSEHOLDS
  HW0(H)        DOF     HHDS    NUMBER OF WORKING HOUSEHOLDS
  IGT0(G,G1)    DOF     NOMINAL INTER GOVERNMENTAL TRANSFERS
  ITC0(I)       DOF     NOMINAL INVESTMENT TAX CREDIT
  KS0(I)        CALC    REAL    CAPITAL STOCK
  M0(I)         IMPLAN  REAL    IMPORTS
  MI0(H)        DOF     REAL    IN MIGRATION
  MO0(H)        DOF     REAL    OUT MIGRATION
  N0(I)         CALC    REAL    GROSS INVESTMENT BY SECTOR OF DESTINATION
  NKI0          CALC    NOMINAL NET CAPITAL INFLOW
  P0(Z)         CALC    PRICE   AGGREGATE PRICES
  PCTINST(F)    UCB     PERCENT OF EARNINGS RETURNED INSTATE
  PD0(I)        CALC    PRICE   DOMESTIC PRICES
  PIT0(G,H)     DOF     NOMINAL TAX PER WORKING HOUSEHOLD
***lingyun test for pit defining pit01
  PIT01(G,H)    DOF     NOMINAL TAX PER WORKING HOUSEHOLD
  PVA0(I)       CALC    PRICE   VALUE ADDED PRICES
  PW0(I)        CALC    PRICE   EXOGENOUS PRICES IN EXTERNAL MARKETS
  Q0(Z)         DOF     REAL    SOCIAL ACCOUNTING MATRIX TOTALS
  R0(F,Z)       IMPLAN  PRICE   INITIAL SECTORAL RENTAL RATE FOR FACTOR
  RA0(F)        IMPLAN  AVERAGE RENTAL RATES FOR FACTORS
  RR0(F,I)      DOF     PRICE   RENTAL RATES INCLUDING TAXES
  S0(Z)         DOF     NOMINAL SAVINGS
  SPI0          CALC    NOMINAL STATE PERSONAL INCOME
  TP0(H,G)      DOF     NOMINAL PER ELIGIBLE HOUSEHOLD TRANSFER PAYMENTS
  V0(I)         IMPLAN  REAL    INTERMEDIATE DEMAND
  YD0(H)        CALC    NOMINAL AFTER TAX TOTAL HOUSEHOLD INCOMES
  YD20(H)       CALC    NOMINAL TOTAL HOUSEHOLD TRANSFERS
  Y0(Z)         CALC    NOMINAL HOUSEHOLD AND GOVERNMENT INCOMES
  Y20(Z)        CALC    NOMINAL HOUSEHOLD TRANSFER INCOMES
  TAXCRED(GI,H) TAX CREDIT FOR EXPERIMENTS
*
* REGULATORY PARAMETERS
*
  CARBRATE      ARB     TAX ON CARBON DIOXIDE IN BILLION DOLLARS PER MILLION METRIC TONS
  CINTENS(I,J)  CAT     REAL    CARBON DIOXIDE INTENSITY IN MILLION METRIC TONS PER BILLION DOLLARS
  DTPVA(TI,K)   CALC    REAL    PVA FOR TECH K COMPARED TO BASELINE TECH
  LUMP(H,G)     UCB     LUMP SUM PAYMENT FROM G TO H
  MACC(I,K)     CAT     MARGINAL ABATEMENT COST COEFFICIENT IN BILLION DOLLARS PER MILLION METRIC TONS
  ORDSCEN(T)    CALC    ORDINAL VALUE OF SCENARIO
  ORDVAL(Z)     CALC    ORDINAL VALUE OF SECTOR PASSED TO REG GMS
  REG1(I,J)     UCB     SCALING OF INTERMEDIATE DEMAND
  REG1_ITK(I)   CALC    TRACKING OF REG1
  REG11(J,TI,K) ARB     PERCENT OFFSET FOR NEW TECH
  REG11_ITK(TI,K) CALC  TRACKING OF REG11
  REG11TRK(J,TI,K) CALC TRACKING OF REG11
  REG16(I,C)    UCB     SCALING OF CONSUMER DEMAND
  REG16TK(I,C)  CALC    TRACKING OF REG16
  REG16TRK(Z)   CALC    TRACKING OF REG16
  REG18(Z,GN)   UCB     SCALING OF GOVERNMENT SPENDING
  REG19(I,K)    CAT     EMISSION REDUCTION POTENTIAL IN MILLION METRIC TONS PER BILLION DOLLARS OUTPUT
  REG1I_TK(I)   CALC    TRACKING OF REG1
  REG1TRK(I,J)  CALC    TRACKING OF REG1
  REGYD(H)      UCB     ENVIRONMENTAL BENEFITS ADDED TO YD FOR MIGRATION
  REGM(I)       UCB     Exogenous addition to imports
  TCINTENS(I)   CAT     REAL  CARBON DIOXIDE INTENSITY OF TRADED GOODS IN MILLION METRIC TONS PER BILLION DOLLARS
  TSEW(TI,K)    CALC    WEIGHT OF EXPONENTIAL TERM IN TSE CALCULATION
  TSEWTSGN(K)   CALC    SIGN ON TSEWTNEG
  TSCALE        UCB     LOGIT PARAMETER   /15/ ;

*
*----------------------------------------------------------------
* 3.3 CALCULATIONS OF PARAMETERS AND INITIAL VALUES
*----------------------------------------------------------------
*
* SENSITIVITY OF MIGRATION TO PUBLIC EDUCATION SPENDING
  ETAED('HOUS0') = 0.5;
  ETAED('HOUS1') = 0.5;
  ETAED('HOUS2') = 0.5;
  ETAED('HOUS4') = 0.4;
  ETAED('HOUS6') = 0.3;
  ETAED('HOUS8') = 0.2;
  ETAED('HOUS9') = 0.1;
  ETAED('HOUSH') = 0.1;
*
* POLICY WEIGHTS OF INFRASTRUCURE SPENDING
  KAPPA(GNS) = 1;
*
* FOR SENSITIVITY ANALYSIS EXPERIMENTS
  TAXCRED(GI,H) = 0;
*
* INVESTMENT SUPPLY ELASTICITY IMPOSED
  ETAI(I)       = 20;
*
*
* THE FOLLOWING SIX STEPS COMPRISE A SYSTEMATIC WAY TO BUILD A LARGE MATRIX ( IGTD(G,G) )
* THAT CONTROLS INTER-GOVERNMENTAL TRANSFERS.
* THE ALTERNATIVE WOULD BE TO INPUT EACH NUMBER IN A 35x35 MATRIX.
*
* STEP 1: 1 = ENDOGENOUS (ALTHOUGH MANY OF THESE ARE RESET IN THE NEXT STEPS)
  IGTD(G,GT) = 1;
*
* STEP 2: 2 = EXOGENOUS
  IGTD(G,'FSNON')  = 2;
  IGTD(G,'CGENF')  = 2;
  IGTD(GC,'CSOTH') = 2;
  IGTD(GL,'LSOTH') = 2;
  IGTD(GL,GC)      = 2;
***pb fix the payment from ftsoc to fsnon
  IGTD('fsnon','ftsoc') = 2;
*make fsnon fully exogenous
*  IGTD('FSNON',G) = 2;
***
*
* STEP 3: 3 = CA BUDGET BALANCING AND PROP 98 TRANSFERS
  IGTD(GC,'CGENF')      = 3;
  IGTD('LSK14','CGENF') = 3;
*
* STEP 4: 4 = FOR EXOGENOUS TRANSFER PAYMENTS
  IGTD('LSHTH','FSNON') = 4;
  IGTD('LSHTH','CGENF') = 4;
  IGTD('LSWEL','FSNON') = 4;
  IGTD('LSWEL','CGENF') = 4;
***pb  Step 4.5
* CTREG is anomalous in having cgenf transfers in and also transfers out.
*violates convention that tax units have no transfers in.
  IGTD(G, 'ctreg') = 5;
*
* STEP 5: 0 = NOT ALLOWED FOR PAYMENTS BY GOVT SPENDING UNITS TO FACTOR TAXES EXCLUDED
***pb  permit gov't spending to pay factor taxes
*
  IGTD(GF,GX) = 0;
  IGTD(GF,GN) = 0;
*
***
*
* STEP 6: 0 = NOT ALLOWED IF NOT IN ORIGINAL SAM (SEE MODEL CLOSURE)
  IGTD(G,G1)$( NOT SAM(G,G1) ) = 0;
*
* READ IN ELASTICITY AND OTHER KEY PARAMETERS
  ETAE(I)       = MISC(I,'ETAE');
  ETAGS(I)      = 0.1;
  ETAM(I)       = MISC(I,'ETAM');
  SIGMA(I)      = MISC(I,'SIGMA') ;
  R0('CAPIT',I) = MISC(I,'R0') * 100;
********
* Bill Dean September 8, 2006.
* Peter Berck says R0 should be 0.11; multiply by 100 so FD0 is in units of $100 billion
  R0('CAPIT',I) = 100 * 0.11;
********
  ETARA(H)      = MISCH(H,'ETARA');
  ETAPIT(H)     = MISCH(H,'ETAPIT');
  ETATP(H)      = MISCH(H,'ETATP');
  ETAYD(H)      = MISCH(H,'ETAYD');
  NRPG(H)       = MISCH(H,'NRPG');
  ETAU(H)       = MISCH(H,'ETAU');
  TAXBASE(G,H)  = MISCG(G,H,'TAXBASE');
  TAXBM(G,H)    = MISCG(G,H,'TAXBM');
  TAXSD(G,H)    = MISCG(G,H,'TAXSD');
  TAXOD(G,H)    = MISCG(G,H,'TAXOD');
  TAXPI(G,H)    = MISCG(G,H,'TAXPI');
*lingyun redefine the taxcvc to make pit balance exactly
*TAXCVC(G,H)   = MISCG(G,H,'TAXCVC');
  taxcvc(g,h)=0;
  MTR(G,H)      = MISCG(G,H,'MTR');
* READ IN REGULATORY PARAMETER
*
  REG1(I,J)     = 1;
  REG1TRK(I,J)  = 0;
  REG1I_TK(I)   = 0;
  REG1_ITK(I)   = 0;
  REG11TRK(J,TI,K) = 0;
  REG11_ITK(TI,K) = 0;
  REG16(I,C)    = 1;
  REG16TK(I,C)  = 0;
  REG16TRK(Z)   = 0;
  REGM(I)       = 0;
  LUMP(H,G)     = 0;
  REGYD(H)      = 0;
  CARBRATE      = 0;
  MACC(I,K)     = 0;
  REG19(I,K)    = 0;
  DTPVA(TI,K)   = 0;
  ORDVAL(Z)     = ORD(Z);
  ORDSCEN(T)    = ORD(T);
  REG18(Z,GN) = 1;
  TSEWTSGN(K) = -1;
  TSEWTSGN('1') = 1;
  TSEW(TI,K) = 0.5;
* TIC IS THE COMPLEMENT OF TI IN I.
  TIC(I) = not TI(I);

*** Second cut
* K = 1 is the BAU technology, K >0 are additional technologies
  REG11(J,TI,K) = 0;
  REG11(J,TI,'1') = 1;

* Carbon intensity in million metric tons CO2e per billion dollars of fuel combusted
*
  CINTENS(I,J) = 0;
  TCINTENS(I) = 0;

* For crude oil, 419 kg CO2 per barrel, $26.43 (2003 dollars) per barrel
  CINTENS('OILGAS','OILREF') = 15.85;
* For natural gas, 52.94 kg CO2e per MMBtu, $5.20 (2003 dollars) per mcf, 983 Btu per cf
  CINTENS('OILGAS','DSTGAS') = 9.66;
  CINTENS('OILGAS','DISTEL') = 9.66;
  TCINTENS('DSTGAS') = 9.66;
* For imported electricity, 708 lb CO2 per MWh, $95.19 (2003 dollars) per MWh
  TCINTENS('DISTEL') = 3.38;
* For imported gasoline, 8.55 kg CO2 per gallon, $1.83 (2003 dollars) per gallon
  TCINTENS('OILREF') = 4.67;

**----------------------------------------------------------------
* SAM forecasting               (Ralf)
*----------------------------------------------------------------
$BATINCLUDE FutureYears03.gms
***

*
* CALCULATE COLUMN AND ROW TOTALS OF SAM TO COMPARE FOR BALANCE
* THIS IS REDUNDANT IF THE SAM IS OK, BUT USEFUL IN CALIBRATION
  Q0(Z) = SUM(Z1,SAM(Z,Z1) );

*CAPFOR in order to account for row in YEQ
  CAPFOR('CAPIT')  = SAM('ROW','CAPIT');
  CAPFOR('LABOR')  = SAM('ROW','LABOR');

* Some fraction of carbon tax gets recycled in the state
  PCTINST('CAPIT') = 1.0;
  PCTINST('LABOR') = 0;

* CALCULATE SALES AND EXCISE TAX RATES FROM SAM INFORMATION
  TAUQ(GS,I) = SAM(GS,I) / ( SUM(J, SAM(I,J) ) + SUM(C, SAM(I,C) ) + SUM(G, SAM(I,G) ) + SAM(I,'INVES')
                 - SUM(GS1, SAM(GS1,I) ) );
*
* THEN SET EXPERIMENTAL TAX RATES EQUAL TO INITIAL TAX RATES
  TAUQX(GS,I) = TAUQ(GS,I);
*
* DUTY, FACTOR AND HOUSEHOLD TAXES
  TAUM('FTDUT',I)$(SAM('ROW',I) gt 0) = SAM('FTDUT',I) / SAM('ROW',I);
  TAUF(GF,F,I)$(SAM(F,I) AND TAUFF(GF,F)) = SAM(GF,I) / SAM(F,I);
  TAUF(GF,F,G)$(SAM(F,G) AND TAUFF(GF,F)) = SAM(GF,G) / SAM(F,G);
  TAUFX(GF,F,Z) = TAUF(GF,F,Z);
  TAUFH(GF,F)$TAUFF(GF,F) = SAM(GF,F) / SUM(Z, SAM(Z,F));
*
* SET DISTRIBUTION SHARES FOR ENDOGENOUS TAX TRANSFERS
  TAXS(G,GT)$( SUM(G1, SAM(G1,GT) ) - SUM(GF, SAM(GF,GT) ) ) =
  SAM(G,GT) / ( SUM(G1, SAM(G1,GT) ) - SUM(GF, SAM(GF,GT) ) );
*
* SET INITIAL INTER GOVERNMENTAL TRANSFERS
  IGT0(G,G1) = SAM(G,G1);
***pb do not set igt0=0 since it is not zero in SAM
  IGT0(GF,G) = 0;
***
*
* SET INITIAL PRICES TO UNITY
  PW0(I)  = 1 / ( 1 + SUM(G, TAUM(G,I) ) );
  P0(Z)   = 1;
  PD0(I)  = 1;
  CPI0(H) = 1;
*
* NUMBER OF HOUSEHOLDS AND INITIAL TRANSFER PAYMENTS
  HH0(H) = MISCH(H,'HH0');
  HW0(H) = MISCH(H,'HW0');
  HN0(H) = HH0(H) - HW0(H);
  TP0(H,GW)$TPC(H,GW) = SAM(H,GW) / ( HN0(H) * TPC(H,GW) );
*
* FACTOR RENTALS
  JOBCOR  = SUM(H, HW0(H) ) / SUM(Z, MISC(Z,'JOBS') );
  R0('CAPIT',G) = 1;
  R0('LABOR',I) = SAM('LABOR',I) / MISC(I,'JOBS');
*lingyun R0('LABOR',G) change to fix yfeq not equal at initial point by adjust ccm table
*R0('LABOR',G) = SAM('LABOR',G);
  R0('LABOR',G)$MISC(G,'JOBS') = SAM('LABOR',G) / MISC(G,'JOBS');
  FD0('LABOR',I) = MISC(I,'JOBS');
  FD0('CAPIT',I) = SAM('CAPIT',I) / R0('CAPIT',I);
*lingyun FD0('LABOR',G) change to fix yfeq not equal at initial point
* FD0('LABOR',G) = 1;
  FD0('LABOR',G) = MISC(G,'JOBS');
  FD0('CAPIT',G) = SAM('CAPIT',G) / R0('CAPIT',G);
  KS0(I) = FD0('CAPIT',I);
*
* SHARES FOUND IN THE SOCIAL ACCOUNTING MATRIX DATA
  A(Z,Z1) = SAM(Z,Z1) / Q0(Z1);
  AG(I,G)$(SUM(J, SAM(J,G) ) + SUM(F, SAM(F,G) ) + SUM(GF, SAM(GF,G) ) )
          =  SAM(I,G) / ( SUM(J, SAM(J,G) ) + SUM(F, SAM(F,G) ) + SUM(GF, SAM(GF,G) ) );
  AG(F,G)$(SUM(I, SAM(I,G) ) + SUM(F1, SAM(F1,G) ) + SUM(GF, SAM(GF,G) ) )
          =  SAM(F,G) / ( SUM(I, SAM(I,G) ) + SUM(F1, SAM(F1,G) ) + SUM(GF, SAM(GF,G) ) );
*
* INITIAL MACRO VARIABLES:
* EXPORTS, IMPORTS, INTERMEDIATES, CONSUMPTION, GOVERNMENT, DEPRECIATION, INVESTMENT, DEMAND, SUPPLY
  CX0(I)   = SAM(I,'ROW');
  M0(I)    = SAM('ROW',I) / PW0(I);
  V0(I)    = SUM(J, SAM(I,J)  / ( 1 + SUM(GS, TAUQ(GS,I) ) ) );
  CH0(I)   = SUM(C, SAM(I,C)  / ( 1 + SUM(GS, TAUQ(GS,I) ) ) );
  CG0(I,G) = SAM(I,G) / P0(I) / ( 1 + SUM(GS, TAUQ(GS,I) ) );
  DEPR     = SUM(I, SAM(I,'INVES') ) / SUM(I, KS0(I) );
  N0(I)    = KS0(I) * DEPR;
  CN0(I)   = SUM(J, CCM(I,J) * N0(J) ) / P0(I) / ( 1 + SUM(GS, TAUQ(GS,I) ) );
  DD0(I)   = CH0(I) + SUM(G, CG0(I,G) ) + SAM(I,'INVES')/ ( 1 + SUM(GS, TAUQ(GS,I) ) ) + V0(I);
*  DD0(I)   = CH0(I) + SUM(G, CG0(I,G) ) + CN0(I) + V0(I);
  DS0(I)   = DD0(I) + CX0(I) - M0(I);
*
*
* PRODUCTION DATA
  AD(I,J)        = SAM(I,J) / P0(I) / ( 1 + SUM(GS, TAUQ(GS,I) ) ) / DS0(J);
  ALPHACG(I,GNS) = CG0(I,GNS) / SUM(J, CG0(J,GNS) );
  ALPHAFG(F,GNS) = FD0(F,GNS) / SUM(F1, FD0(F1,GNS) );
  PVA0(I)        = PD0(I) - SUM(J, AD(J,I) * P0(J) * ( 1 + SUM(GS, TAUQ(GS,J) ) ) );
  RA0(F)         = 1;
  E0(I)          = 1;
  GST0           = SUM(GNS, KAPPA(GNS) * ( SUM(J, ALPHACG(J,GNS) * CG0(J,GNS) * P0(J) )
                                       + SUM(F, ALPHAFG(F,GNS) * FD0(F,GNS) * R0(F,GNS) * RA0(F) ) ) );
*
* CARBON TRADING DATA
  CARBON0(I) = SUM(TI, (AD(TI,I) * (DS0(I) )) * CINTENS(TI,I));
*  Until we figure out a way to impose a carbon tax on imports, we better not include imports in calculation of
*  revenue recycling.
*  CARBON0(I) = SUM(TI, (AD(TI,I) * (DS0(I)+ M0(I) - CX0(I))) * CINTENS(TI,I));
*
* MISCELLANEOUS INITIAL DATA
*lingyun fix nki by changing the value of nki0
  NKI0       = SAM('INVES','ROW')-SAM('ROW','CAPIT');
*NKI0       = SAM('INVES','ROW');
  Y0(F)      = Q0(F);
  Y0(H)      = SUM(F, SAM(H,F) );
  Y20(G)     = SUM((I,J), TAUQX(G,I) * P0(I) * AD(I,J) * DS0(J) ) + SUM(I, TAUM(G,I) * M0(I) * PW0(I) )
                  + SUM(I, TAUQX(G,I) * (CH0(I) + CN0(I)) * P0(I) );
*LINGYUN CHANGE HW0 TO HH0 to make our definition consistent
  A(H,F)     = SAM(H,F) / HH0(H) / Y0(F);
  TAUH(GH,H) = SAM(GH,H) / HH0(H);
  S0(H)      = SAM('INVES',H);
  YD0(H)     = SUM(C, SAM(C,H) ) + S0(H);
  YD20(H)    = SUM(G, TP0(H,G) * HN0(H) * TPC(H,G)) ;
***pb added payments to row as part of exog savings for gov't
*savings is the net payments to the rest of the world or to investment
  S0(G)      = SAM('INVES',G)+ SAM('ROW',G)- SAM(G,'INVES') - SAM(G,'ROW');
***pb added in s0 to remove exogenous income and expense
*TAX income is all sources, less transfers, less exogenous income
  Y0(G)      = SUM(Z, SAM(G,Z) ) - SUM(G1, IGT0(G,G1) )- SAM(G,'INVES') - SAM(G,'ROW');
*LINGYUN CHANGE HW0(H) TO HH(H) to make our definition consistent
  AGI0(H)    = SUM(F, OMEGA(F) * SAM(H,F) ) / HH0(H);
  SPI0       = SUM(H, Y0(H) ) + SUM((H,GW), TP0(H,GW) * HN0(H) * TPC(H,GW) );
*LINGYUN CHANGE HW0 TO HH0 to make our definition consistent
  PIT0(GI,H) = SAM(GI,H) / HH0(H);
*
  MIGRFACTOR = 0.09;
  MI0(H)     = MIGRFACTOR * HH0(H);
  MO0(H)     = MIGRFACTOR * HH0(H);
*
* INVESTMENT TAX CREDIT AND CORRECTION TO GROSS CA PROFITS TAXES
  FITC(F,G)                = 0;
  FITC('CAPIT','CTBAC')    = 1;
  ITC0(I)                  = SUM(J, N0(I) * CCM(J,I) / ( 1 + SUM(GS, TAUQ(GS,J) ) ) * ITCE(J,I) );
  TAUF('CTBAC','CAPIT',I)  = ( SAM('CTBAC',I) + ITC0(I) ) / SAM('CAPIT',I);
  TAUFX('CTBAC','CAPIT',I) = TAUF('CTBAC','CAPIT',I);
*
* CES PRODUCTION FUNCTION CALIBRATION
  ALPHA(F,I) = ( SAM(F,I) + SUM(GF, TAUFF(GF,F) * SAM(GF,I) ) ) / ( SUM(F1, SAM(F1,I) ) + SUM(GF, SAM(GF,I) ) );
  RR0(F,I)   = R0(F,I) * RA0(F) * ( 1 + SUM(GF, TAUFX(GF,F,I) ) ) - SUM(GF,  FITC(F,GF) * ITC0(I) ) / FD0(F,I);
*
* INITIAL CALIBRATION OF CONSUMPTION FUNCTIONS
  SIGMAH(H)     = SAM('INVES',H) / YD0(H);
  CS0(C,H)      = SAM(C,H) / SUM(C1, SAM(C1,H) );
  BETA('CFUEL') = BETA('CFUEL') - SUM(C1, BETA(C1) );
  ALPHA0(C,H)   = CS0(C,H) - BETA(C) * LOG( YD0(H) * ( 1 - SIGMAH(H) ) );
  PHI(I,C)      = SAM(I,C) / SUM(J, SAM(J,C) );
  LOOP(C, LOOP(C1$( ORD(C1) GT ORD(C) ), LAMBDA(C,C1) = LAMBDA(C1,C) ) );
  LAMBDA(C,C)   = LAMBDA(C,C) - SUM(C1, LAMBDA(C1,C) );
*
* INITIAL GOVERNMENT SPENDING ON PUBLIC EDUCATION
  GSED0 = SUM(GED, SUM(G, IGT0(GED,G) ) );
*
*----------------------------------------------------------------
* 4. VARIABLES
*----------------------------------------------------------------
* 4.1 VARIABLE DECLARATION
*----------------------------------------------------------------
*
  VARIABLES
*
  AGI(H)    THOUSAND    DOLLARS AVERAGE AGI FOR PIT PURPOSES
  CARBCAP   MILLION     METRIC TONS CARBON DIOXIDE CAP
  CARBON(I) MILLION     METRIC TONS CARBON DIOXIDE EMISSIONS
  CG(I,G)   BILLION     DOLLARS PUBLIC CONSUMPTION
  CH(I)     BILLION     DOLLARS PRIVATE CONSUMPTION
  CN(I)     BILLION     DOLLARS GROSS INVESTMENT BY SECTOR OF SOURCE
  CPI(H)    PRICE       INDEX 1 CONSUMER PRICE INDEX
  CS(C,H)   SHARES      TOTAL 1 CONSUMPTION SHARES OF YD LESS SAVINGS
  CX(I)     BILLION     DOLLARS EXPORT DEMAND
  DD(I)     BILLION     DOLLARS DOMESTIC DEMAND
  DS(I)     BILLION     DOLLARS DOMESTIC SUPPLY
  E(I)      NUMBER      INFRASTRUCTURE SCALE VARIBALE IN PRODUCTION FUNCTIONS
  FD(F,Z)   BILLION     DOLLARS SECTORAL FACTOR DEMAND
  GST       BILLION     DOLLARS TOTAL GOVERNMENT SPENDING INCLUDING FACTOR RENTALS
  GSED      BILLION     DOLLARS TOTAL GOVERNMENT SPENDING ON EDUCATION
  HH(H)     MILLIONS            NUMBER OF HOUSEHOLDS
  HN(H)     MILLIONS            NUMBER OF NONWORKING HOUSEHOLDS
  HW(H)     MILLIONS            NUMBER OF WORKING HOUSEHOLDS
  IGT(G,G1) BILLION     DOLLARS INTER GOVERNMENTAL TRANSFERS
  ITC(I)    BILLION     DOLLARS INVESTMENT TAX CREDIT AMOUNT
  KS(I)     100 BILLION DOLLARS CAPITAL STOCK
  M(I)      BILLION     DOLLARS IMPORTS
  N(I)      BILLION     DOLLARS GROSS INVESTMENT BY SECTOR OF DESTINATION
  NKI       BILLION     DOLLARS NET CAPITAL INFLOW
*  OFFSET(I) PERCENT     COMPARES OFFSET WITH DOMESTIC SUPPLY
  P(Z)      PRICE               AGGREGATE DOMESTIC PRICE PAID BY PURCHASERS
  PD(I)     PRICE               DOMESTIC PRICE RECEIVED BY SUPPLIERS
  PIT(G,H)  THOUSAND    DOLLARS PER HOUSEHOLD INCOME TAXES
  PVA(I)    PRICE               VALUE ADDED PRICE
  RA(F)     PRICE               ECONOMY WIDE SCALAR RENTAL RATES OF FACTORS
  R(F,Z)    PRICE               SECTORAL RENTAL RATES
  RR(F,Z)   PRICE               RENTAL RATES INCLUDING TAXES
  S(Z)      BILLION     DOLLARS SAVINGS
  SPI       BILLION     DOLLARS STATE PERSONAL INCOME
  TP(H,G)   THOUSAND    DOLLARS GOVERNMENT TRANSFER PAYMENTS
  TPVA(TI,K) BILLION    PVA FOR TECH K
  TSE(TI,K) PERCENT     SHARE OF TECH K
  TSUM(TI)   BILLION    DENOMINATOR OF LOGIT
  V(I)      BILLION     DOLLARS INTERMEDIATE GOODS
  VREG1(I,J) PERCENT    COST MINIMIZING CHANGE IN TECHNOLOGY IN USE
  Y(Z)      BILLION     DOLLARS GROSS INCOMES
  YD(H)     BILLION     DOLLARS AFTER TAX TOTAL HOUSEHOLD INCOMES
*~ka estimate GSP June08
  YD2(H)    BILLION     DOLLARS TOTAL HOUSEHOLD TRANSFERS
  Y2(Z)     BILLION     TRANSFERS;
*FREE VARIABLE
*OB  BILLION;
* FV.FX(GC)=0;
*  FV.LO('CSK14')=-100000;
*  FV.UP('CSK14')=100000;
*----------------------------------------------------------------
* 4.2 INITIALIZATION OF VARIABLES
*----------------------------------------------------------------
*
  P.L(Z)      = P0(Z);          PD.L(I)     = PD0(I);          PVA.L(I)    = PVA0(I);        RA.L(F)     = RA0(F);
  R.L(F,Z)    = R0(F,Z);        CPI.L(H)    = CPI0(H);         DS.L(I)     = DS0(I);         DD.L(I)     = DD0(I);
  V.L(I)      = V0(I);          FD.L(F,Z)   = FD0(F,Z);        HH.L(H)     = HH0(H);         HN.L(H)     = HN0(H);
  HW.L(H)     = HW0(H);         KS.L(I)     = KS0(I);          CN.L(I)     = CN0(I);         N.L(I)      = N0(I);
  CX.L(I)     = CX0(I);         M.L(I)      = M0(I);           NKI.L       = NKI0;           TP.L(H,G)   = TP0(H,G);
  Y.L(Z)      = Y0(Z);          YD.L(H)     = YD0(H);          YD2.L(H)     = YD20(H);
  Y2.L(G)     = Y20(G);         PIT.L(G,H)  = PIT0(G,H);       IGT.L(G,G1) = IGT0(G,G1);
  CH.L(I)     = CH0(I);         CG.L(I,G)   = CG0(I,G);        S.L(Z)      = S0(Z);          SPI.L       = SPI0;
  ITC.L(I)    = ITC0(I);        AGI.L(H)    = AGI0(H);         RR.L(F,I)   = RR0(F,I);       CS.L(C,H)   = CS0(C,H);
  E.L(I)      = E0(I);          GST.L      = GST0;             GSED.L      = GSED0;
  CARBCAP.L   = SUM(I,CARBON0(I) + (M0(I)-CX0(I)) * TCINTENS(I));     TSUM.L(TI)  = 1;
* Some variables are not computed for I in TIC.
  CARBON.L(TI) = CARBON0(TI);   CARBON.FX(TIC) = CARBON0(TIC);
  TSE.L(TI,'1') = 1;            TSE.UP(TI,K) = 1;             TSE.LO(TI,K) = 0;
* VREG is not computed for I in TIC and so is fixed at 1.
  VREG1.L(I,TI) = 1;    VREG1.FX(I,TIC) = 1;
*
*----------------------------------------------------------------
* 4.3 REMOVING TRACE NUMBERS FOR COMPUTATIONAL PURPOSES
*----------------------------------------------------------------
*
  P.L(Z)$(ABS(P.L(Z))           LT 0.00000001) = 0;     PD.L(I)$(ABS(PD.L(I))         LT 0.00000001) = 0;
  PVA.L(I)$(ABS(PVA.L(I))       LT 0.00000001) = 0;     RA.L(F)$(ABS(RA.L(F))         LT 0.00000001) = 0;
  R.L(F,Z)$(ABS(R.L(F,Z))       LT 0.00000001) = 0;     CPI.L(H)$(ABS(CPI.L(H))       LT 0.00000001) = 0;
  DS.L(I)$(ABS(DS.L(I))         LT 0.00000001) = 0;     DD.L(I)$(ABS(DD.L(I))         LT 0.00000001) = 0;
  E.L(I)$(ABS(E.L(I))           LT 0.00000001) = 0;     V.L(I)$(ABS(V.L(I))           LT 0.00000001) = 0;
  FD.L(F,Z)$(ABS(FD.L(F,Z))     LT 0.00000001) = 0;     GST.L$(ABS(GST.L)             LT 0.00000001) = 0;
  HH.L(H)$(ABS(HH.L(H))         LT 0.00000001) = 0;     HN.L(H)$(ABS(HN.L(H))         LT 0.00000001) = 0;
  HW.L(H)$(ABS(HW.L(H))         LT 0.00000001) = 0;     KS.L(I)$(ABS(KS.L(I))         LT 0.00000001) = 0;
  CN.L(I)$(ABS(CN.L(I))         LT 0.00000001) = 0;     N.L(I)$(ABS(N.L(I))           LT 0.00000001) = 0;
  CX.L(I)$(ABS(CX.L(I))         LT 0.00000001) = 0;     M.L(I)$(ABS(M.L(I))           LT 0.00000001) = 0;
  NKI.L$(ABS(NKI.L)             LT 0.00000001) = 0;     TP.L(H,G)$(ABS(TP.L(H,G))     LT 0.00000001) = 0;
  Y.L(Z)$(ABS(Y.L(Z))           LT 0.00000001) = 0;     YD.L(H)$(ABS(YD.L(H))         LT 0.00000001) = 0;
  PIT.L(G,H)$(ABS(PIT.L(G,H))   LT 0.00000001) = 0;     IGT.L(G,G1)$(ABS(IGT.L(G,G1)) LT 0.00000001) = 0;
  CH.L(I)$(ABS(CH.L(I))         LT 0.00000001) = 0;     CG.L(I,G)$(ABS(CG.L(I,G))     LT 0.00000001) = 0;
  S.L(Z)$(ABS(S.L(Z))           LT 0.00000001) = 0;     SPI.L$(ABS(SPI.L)             LT 0.00000001) = 0;
  AGI.L(H)$(ABS(AGI.L(H))       LT 0.00000001) = 0;
*
*----------------------------------------------------------------
* 4.3 SETTING COMPUTATIONALLY USEFUL BOUNDS ON VARIABLES (TO HELP THE SOLVER)
*----------------------------------------------------------------
*
*  AGI.LO(H)    = AGI0(H)     / 1000;  AGI.UP(H)    = AGI0(H)     * 1000;
* CG.LO(I,G)   = CG.L(I,G)   / 1000;  CG.UP(I,G)   = CG.L(I,G)   * 1000;
  CH.LO(I)     = CH.L(I)     / 1000;  CH.UP(I)     = CH.L(I)     * 1000;
  CN.LO(I)     = 0;
  CPI.LO(H)    = CPI.L(H)    / 1000;  CPI.UP(H)    = CPI.L(H)    * 1000;
  CS.LO(C,H)   = CS0(C,H)    / 1000;  CS.UP(C,H)   = 1                 ;
  CX.LO(I)     = CX.L(I)     / 1000;  CX.UP(I)     = CX.L(I)     * 1000;
  DD.LO(I)     = DD.L(I)     / 1000;  DD.UP(I)     = DD.L(I)     * 1000;
  DS.LO(I)     = DS.L(I)     / 1000;  DS.UP(I)     = DS.L(I)     * 1000;
  E.LO(I)      = 0;                   E.UP(I)      = E.L(I)      *    2;
  FD.LO(F,Z)   = FD.L(F,Z)   / 1000;  FD.UP(F,Z)   = FD.L(F,Z)   * 1000;
  GST.LO       = GST.L       / 1000;  GST.UP       = GST.L       * 1000;
  HH.LO(H)     = HH.L(H)     / 1000;  HH.UP(H)     = HH.L(H)     * 1000;
  HN.LO(H)     = HN.L(H)     / 1000;  HN.UP(H)     = HN.L(H)     * 1000;
  HW.LO(H)     = HW.L(H)     / 1000;  HW.UP(H)     = HW.L(H)     * 1000;
*IGT.LO(G,G1) = IGT.L(G,G1) / 1000;  IGT.UP(G,G1) = IGT.L(G,G1) * 1000;
* ITC.LO(I)    = ITC.L(I)    / 1000;  ITC.UP(I)    = ITC.L(I)    * 1000;
  KS.LO(I)     = KS.L(I)     / 1000;  KS.UP(I)     = KS.L(I)     * 1000;
  M.LO(I)      = M.L(I)      / 1000;  M.UP(I)      = M.L(I)      * 1000;
  N.LO(I)      = 0;
* NKI -- SIGN CAN CHANGE, THUS BOUNDS ARE INAPPROPRIATE
  P.LO(Z)      = P.L(Z)      / 1000;  P.UP(Z)      = P.L(Z)      * 1000;
  PD.LO(I)     = PD.L(I)     / 1000;  PD.UP(I)     = PD.L(I)     * 1000;
* PIT.LO(GI,H) = 0;
  PVA.LO(I)    = PVA.L(I)    / 1000;  PVA.UP(I)    = PVA.L(I)    * 1000;
  R.LO(F,I)    = R.L(F,I)    / 2   ;  R.UP(F,I)    = R.L(F,I)    * 2;
  RA.LO(F)     = RA.L(F)     / 1000;  RA.UP(F)     = RA.L(F)     * 1000;
* S -- SIGN CAN CHANGE, THUS BOUNDS ARE INAPPROPRIATE
  TP.LO(H,G)   = TP.L(H,G)   / 1000;  TP.UP(H,G)   = TP.L(H,G)   * 1000;
  V.LO(I)      = V.L(I)      / 1000;  V.UP(I)      = V.L(I)      * 1000;
  Y.LO(I)      = Y.L(I)      / 1000;  Y.UP(I)      = Y.L(I)      * 1000;
  YD.LO(H)     = YD.L(H)     / 1000;  YD.UP(H)     = YD.L(H)     * 1000;
  RR.LO(F,I)   = RR.L(F,I)   / 1000;  RR.UP(F,I)   = RR.L(F,I)   * 1000;
*
***Peter Lingyun's other pit0
PIT01(GI,H) = ( TAXBASE(GI,H)+ TAXCVC(GI,H) + ( AGI0(H) - TAXBM(GI,H)- TAXSD(GI,H) -
              ( TAXOD(GI,H) + SUM(GI1, ATAX(GI1,GI) * PIT.l(GI1,H) ) ) * TAXPI(GI,H) ) * MTR(GI,H) ) - TAXCRED(GI,H) ;
TAXCVC(gi,h)=PIT0(GI,H)-PIT01(GI,H);
PIT01(GI,H) = ( TAXBASE(GI,H)+ TAXCVC(GI,H) + ( AGI0(H) - TAXBM(GI,H)- TAXSD(GI,H) -
              ( TAXOD(GI,H) + SUM(GI1, ATAX(GI1,GI) * PIT.l(GI1,H) ) ) * TAXPI(GI,H) ) * MTR(GI,H) ) - TAXCRED(GI,H) ;
*
*display pit01, pit0,taxcvc;
*
*
*----------------------------------------------------------------
* 5. PRE-MODEL CHECK OF PARAMETERS AND INITIAL VALUES OF VARIABLES
*----------------------------------------------------------------
* 5.1 PRINTING CALCULATED PARAMETERS AND EXOGENOUS VARIABLES
*----------------------------------------------------------------
*
* DISPLAY DEPR, JOBCOR, FD0, TAUM, TAUF, TAUFH, ALPHA, ALPHACG, ALPHAFG, CG0, FD0, GST0, R0, RR0,
*         AG, AD, A, ALPHA, SIGMA, CS0, ALPHA0, SIGMAH, LAMBDA, P0;
*

*
*
*----------------------------------------------------------------
* 6. EQUATIONS
*----------------------------------------------------------------
* 6.1 EQUATION DECLARATION
*----------------------------------------------------------------
*
  EQUATIONS
*
* HOUSEHOLDS
  CPIEQ(H)      1.01 CONSUMER PRICE INDICES
  YEQ(H)        1.02 HOUSEHOLD GROSS INCOME
  YDEQ(H)       1.03 HOUSEHOLD DISPOSABLE INCOME
  CSEQ(C,H)     1.04 HOUSEHOLD CONSUMPTION SHARES
  CHEQ(I)       1.05 TOTAL CONSUMPTION OF GOODS AND SERVICES
  CCPEQ(C)      1.06 COMPOSITE COMMODITY PRICES
  SHEQ(H)       1.07 HOUSEHOLD SAVINGS
*~ka estimate GSP June08
  YDEQ2(H)      1.08 HOUSEHOLD TOTAL TRANSFERS
*
* PRODUCERS
  PVAEQ(I)      2.01 VALUE ADDED PRICE
  PCEQ(I)       2.02 COST FUNCTION
  GSTEQ         2.03 TOTAL STATE GOVERNMENT SPENDING
  EEQ(I)        2.04 INFRASTRUCTURE SCALE VARIABLE
  RREQ(F,I)     2.05 RENTAL RATES INCLUDING TAXES
  FDEQ(F,I)     2.06 FACTOR DEMAND
  VEQ(I)        2.07 DEMAND FOR INTERMEDIATE GOODS BY SOURCE
  YFEQ(F)       2.08 FACTOR INCOME
  TSUMQ(TI)     2.09 SUM OF EXP OF DIFF IN PVA
  TSEQ(TI,K)    2.10 LOGIT SHARE
  TREGQ(J,TI)   2.11 VREG1 AS FUNCTION OF REG11 AND SHARE
  CARBEQ(TI)    2.12 CARBON TRADING
  CCAPEQ        2.13 CARBON CAP
*
* TRADE
  XEQ(I)        3.01 EXPORT DEMAND
  MEQ(I)        3.02 IMPORT SUPPLY
  PEQ(I)        3.03 AVERAGE PRICE FACED BY DOMESTIC CONSUMPTION
  NKIEQ         3.04 NET CAPITAL INFLOW
*
* INVESTMENT
  NEQ(I)        4.01 INVESTMENT BY SECTOR OF DESTINATION
  CNEQ(I)       4.02 INVESTMENT BY SECTOR OF SOURCE
  KSEQ(I)       4.03 DESIRED CAPITAL STOCK
  ITCEQ(I)      4.04 INVESTMENT TAX CREDIT EARNED
*
* LABOR SUPPLY AND MIGRATION
  LSEQ(H)       5.01 LABOR SUPPLY
  POPEQ(H)      5.02 MIGRATION
  ANEQ(H)       5.03 NUMBER OF NON-WORKING HOUSEHOLDS
*
* HOUSEHOLD INCOME TAXATION
  AGIEQ(H)      6.01 ADJUSTED GROSS INCOMES
  PITEQ(GI,H)   6.02 INCOME TAXES
*
* GOVERNMENT
  YGEQ(G)       7.01 GOVERNMENT TAX INCOMES
*~ka estimate GSP June08
  YGEQ2(G)      7.015 GOVERNMENT TRANSFERS
  CGNEQ(I,GN)   7.02 ENDOGENOUS GOVERNMENT CONSUMPTION
  GFNEQ(F,GN)   7.03 ENDOGENOUS GOVERNMENT FACTOR RENTALS
  CGXEQ(I,GX)   7.04 EXOGENOUS GOVERNMENT CONSUMPTION
  GFXEQ(F,GX)   7.05 EXOGENOUS GOVERNMENT FACTOR RENTALS
  TDEQ(G,GT)    7.06 DISTRIBUTION OF TAX REVENUES TO SPENDING DESTINATIONS
***PB
  TDEQ2(G,GT)   7.065 DISTRIBUTION OF ALL REVENUES FOR CTREG TO SPENDING DESTINATIONS
  TPGTEQ(GW,G1) 7.07 IGT FOR TRANSFER PAYMENTS
  GFBALEQ       7.08 BALANCE OF GENERAL FUND TO WELFARE PAYMENTS
  GSEQ(G)       7.09 GOVERNMENT SAVINGS
* PROP98        7.10 PROPOSITION 98 TRANSFER FOR EDUCATION -- TEST 2
  PROP98        7.11 PROPOSITION 98 TRANSFER FOR EDUCATION -- TEST 3
  GSEDEQ        7.12 EDUCATION SPENDING
*
* MODEL CLOSURE
  SPIEQ         8.01 ARTIFICIAL OBJECTIVE FUNCTION -- TOTAL STATE PERSONAL INCOMES
  LMEQ          8.02 LABOR MARKET EQUILIBRIUM
  KMEQ(I)       8.03 CAPITAL MARKETS EQUILIBRIUM
  GMEQ(I)       8.04 GOODS AND SERVICES MARKETS EQUILIBRIUM
  DDEQ(I)       8.05 DOMESTIC DEMAND DEFINITION;
*LINGYUN ADD EQUATION
*EQUATION
*FVPOWER(CSK)   8.06 MAKE FV POSITIVE;
*
* FOR REFERENCE PURPOSES THE FOLLOWING ARE LISTED ALONG WITH EQUATIONS,
* ALTHOUGH THE GAMS SPECIFICATION OF FIXING VARIABLES TO LEVELS
* WAS USED FOR ITS COMPUTATIONAL PROPERTIES
*
*               9.01 FIX PIT FOR NON INCOME TAX UNITS TO ZERO
*               9.02 FIX INTER GOVERNMENTAL TRANSFERS TO ZERO IF NOT IN ORIGINAL SAM
*               9.03 FIX EXOGENOUS INTERGOVERNMENTAL TRANSFERS
*               9.04 FIX GOVERNMENT DEMAND FOR GOODS AND SERVICES TO ZERO IF NOT IN ORIGINAL DATA
*               9.05 FIX GOVERNMENT DEMAND FOR FACTORS TO ZERO IF NOT IN ORIGINAL DATA
*               9.06 FIX INTER SECTORAL WAGE DIFFERENTIALS
*               9.07 FIX GOVERNMENT RENTAL RATE FOR CAPITAL TO INITIAL LEVEL
*               9.08 FIX ECONOMY WIDE SCALAR FOR CAPITAL
*               9.09 FIX EXOGENOUS TRANSFER PAYMENT LEVELS
*               9.10 FIX TRANSFER PAYMENTS TO ZERO IF NOT IN ORIGINAL DATA
*
*----------------------------------------------------------------
* 6.2 EQUATION ASSIGNMENT
*----------------------------------------------------------------
*
*----------------------------------------------------------------
* 6.2.1 HOUSEHOLDS
*----------------------------------------------------------------
*
*  1.01 CONSUMER PRICE INDICES
*
  CPIEQ(H).. LOG( CPI(H) ) =E= SUM(C, CS(C,H) * LOG( P(C) ) );
*
*  1.02 HOUSEHOLD GROSS INCOME
*LINGYUN CHANGE HW TO HH   ADD CAPFOR TO FIX YEQ
***pb add carbon tax back into income, March 6, 2007
  YEQ(H).. Y(H) =E= SUM(F, A(H,F) * HH(H) / SUM(H1, A(H1,F) * HH(H1) )* (Y(F)-CAPFOR(F))* ( 1 - SUM(G, TAUFH(G,F) ) ) )
                    + SUM(G,LUMP(H,G));
*
*  1.03 HOUSEHOLD DISPOSABLE INCOME
*LINGYUN CHANGE HW TO HH     SUBSTRACT SAM('FTSOC',H) FROM LEFT SIDE TO MAKE YDEQ CONFROM TO ITS DEF
*  YDEQ(H).. YD(H) =E= Y(H) - SUM(GI, PIT(GI,H) ) * HH(H) - SUM(G, TAUH(G,H) * HH(H) ) +
*                      SUM(G, TP(H,G) * HN(H) * TPC(H,G) )-SAM('FTSOC',H);
* Lump(H,G) is a payment from G to H in lump sum fashion
  YDEQ(H).. YD(H) =E= Y(H) - SUM(GI, PIT(GI,H) ) * HH(H) - SUM(G, TAUH(G,H) * HH(H) ) +
                      SUM(G, TP(H,G) * HN(H) * TPC(H,G) );
*
*  1.04 HOUSEHOLD CONSUMPTION SHARES
*
*  CSEQ(C,H).. CS(C,H) =E= ALPHA0(C,H) + SUM(C1, LAMBDA(C1,C) * LOG( P(C1) ) ) +
*                       BETA(C) * LOG ( YD(H) * ( 1 - SIGMAH(H) ) / CPI(H) );
   CSEQ(C,H).. CS(C,H) =E= CS0(C,H);
*
*  1.05 TOTAL CONSUMPTION OF GOODS AND SERVICES BY HOUSEHOLDS
*
  CHEQ(I).. CH(I) =E= SUM(C, REG16(I,C) *PHI(I,C) *
                      SUM(H, CS(C,H) * ( YD(H) - S(H) ) ) ) / ( P(I) * ( 1 + SUM(GS, TAUQX(GS,I) ) ) );
*
*  1.06 COMPOSITE COMMODITY PRICES
*
  CCPEQ(C).. P(C) =E=   SUM(I, REG16(I,C) *PHI(I,C) * P(I)  *
                        ( 1 + SUM(GS, TAUQX(GS,I) ) ) ) / SUM(I, PHI(I,C) * P0(I) * ( 1 + SUM(GS, TAUQ(GS,I)  ) ) );
*
*  1.07 HOUSEHOLD SAVINGS
*
  SHEQ(H).. S(H) =E=  SIGMAH(H) * YD(H);
*
*~ka, per Peter's code june04-08 , to get total transfer payments
*
*  1.08 HOUSEHOLD TOTAL TRANSFERS
*
  YDEQ2(H).. YD2(H) =E=   SUM(G, TP(H,G) * HN(H) * TPC(H,G)) ;
*
*----------------------------------------------------------------
* 6.2.2 PRODUCERS
*----------------------------------------------------------------
*
*  2.01 VALUE ADDED PRICE
*
  PVAEQ(I).. PVA(I) =E= PD(I)
                        - SUM(J, AD(J,I) * REG1(J,I) * VREG1(J,I) * P(J) * ( 1 + SUM(GS, TAUQX(GS,J) ) ) )
                        - SUM(J, AD(J,I) * REG1(J,I) * VREG1(J,I) * CINTENS(J,I) * CARBRATE)
                        + SUM(TI$(ORDVAL(TI) EQ ORDVAL(I)),SUM(K$(SUM(J,REG11(J,TI,K))gt 0),TSE(TI,K)*REG19(TI,K))) *
                             CARBRATE;

*
*  2.02 UNIT COST FUNCTION
*
  PCEQ(I).. PVA(I) =E= 1 / E(I) * PVA0(I) *
                        SUM(F, ALPHA(F,I) * ( RR(F,I) / RR0(F,I) ) ** ( 1 - SIGMA(I) ) ) ** ( 1 / ( 1 - SIGMA(I) ) );
*
* 2.03 TOTAL GOVERNMENT SPENDING (CONSUMPTION SPENDING AND FACTOR RENTAL)
*
  GSTEQ.. GST =E= SUM(GNS, KAPPA(GNS) *
                  ( SUM(J, ALPHACG(J,GNS) * CG(J,GNS) * P0(J) ) +
                           SUM(F, ALPHAFG(F,GNS) * FD(F,GNS) * R0(F,GNS) * RA0(F) ) ) );
*
* 2.04 INFRASTRUCTURE VARIABLE
*
  EEQ(I).. E(I) =E= E0(I);
* * ( GST / GST0 ) ** ETAGS(I);
*** Infrasture variable turned off by Peter Berck Feb 15, 2007
* 2.05 RENTAL RATES INCLUDING TAXES
*
  RREQ(F,I).. RR(F,I) =E= R(F,I) * RA(F) * ( 1 + SUM(GF, TAUFX(GF,F,I) ) ) - SUM(GF, FITC(F,GF) * ITC(I) ) / FD(F,I);
*
* 2.06 FACTOR DEMAND
*
  FDEQ(F,I).. FD(F,I) =E= E(I) * FD0(F,I) * DS(I) / DS0(I) *
                          ( ( RR0(F,I) * PVA(I) ) / ( RR(F,I) * PVA0(I) ) ) ** SIGMA(I);
*
* 2.07 DEMAND FOR INTERMEDIATE GOODS BY SOURCE
*
  VEQ(I).. V(I) =E= SUM(J, AD(I,J) * REG1(I,J) * VREG1(I,J) * DS(J) );
*
* 2.08 FACTOR INCOME
*
*** Includes carbon tax recycling from in-state and imports, by Peter Berck Aug 17, 2007
  YFEQ(F).. Y(F) =E= SUM(Z,   R(F,Z) * RA(F)* FD(F,Z) ) + CARBRATE * PCTINST(F) * SUM(I,CARBON(I))
             + SUM(I,(M(I)-CX(I)) * PW0(I) *TCINTENS(I) * CARBRATE * PCTINST(F));
*
* 2.09 SUM OF EXP OF DIFF IN PVA
*
  TSUMQ(TI).. TSUM(TI) =E= SUM(K$(SUM(J,REG11(J,TI,K))gt 0),
                                                           TSEW(TI,K) * EXP(DTPVA(TI,K) * TSCALE) +
                                                           TSEWTSGN(K) *
                                                           (1-TSEW(TI,K)) * EXP(DTPVA(TI,'1')*TSCALE));
*
* 2.10 LOGIT SHARE
*
  TSEQ(TI,K)$(SUM(J,REG11(J,TI,K))gt 0) .. TSE(TI,K) =E= (TSEW(TI,K) * EXP(DTPVA(TI,K) * TSCALE) +
                                                          TSEWTSGN(K) *
                                                          (1-TSEW(TI,K)) * EXP(DTPVA(TI,'1') * TSCALE)) /
                                                         TSUM(TI);
*
* 2.11 VREG1 AS FUNCTION OF REG11 AND SHARE
*
  TREGQ(J,TI)..  VREG1(J,TI) =E=  SUM(K,REG11(J,TI,K)*TSE(TI,K));
*
* 2.12 CARBON TRADING
*
  CARBEQ(TI).. CARBON(TI) =E= SUM(J,(AD(J,TI) * (REG1(J,TI)*VREG1(J,TI)*DS(TI) )) * CINTENS(J,TI))
                            - DS(TI) * SUM(K$(SUM(J,REG11(J,TI,K))gt 0),TSE(TI,K)*REG19(TI,K));
*  Until we figure out a way to impose a carbon tax on imports, we better not include imports in calculation of
*  revenue recycling.
*  CARBEQ(TI).. CARBON(TI) =E= SUM(J,(AD(J,TI) * (REG1(J,TI)*VREG1(J,TI)*DS(TI) + M(TI) - CX(TI))) * CINTENS(J,TI))
*                            - DS0(TI) * SUM(K$(SUM(J,REG11(J,TI,K))gt 0),TSE(TI,K)*REG19(TI,K));
*
* 2.13 CARBON CAP
*
  CCAPEQ.. CARBCAP =E= SUM(I,CARBON(I)) + SUM(I,(M(I)-CX(I)) * TCINTENS(I));
*
*
*----------------------------------------------------------------
* 6.2.3 TRADE
*----------------------------------------------------------------
*
* 3.01 EXPORT DEMAND
* original
*  XEQ(I).. CX(I) =E= CX0(I) * ( PD(I) / PD0(I) ) ** ETAE(I);
* august 17 carb tax for trade
  XEQ(I).. CX(I) =E= CX0(I) * ( (PD(I)/(PW0(I)*(1+ TCINTENS(I) * CARBRATE))) / (PD0(I)/PW0(I)) ) ** ETAE(I);
*
* Bill Dean, Peter Berck, Winnie Kam, April 27, 2007.
* We replaced the import elasticities in MSC120.gms with Armington elasticities.
* Also we modified the export import equation by including DD/DD0.
* 3.02 IMPORT SUPPLY
*
  MEQ(I).. M(I) =E= M0(I) * ( PD(I) / PD0(I) ) ** ETAM(I) + REGM(I);
*no armington
*  MEQ(I).. M(I)* DD0(I) =E= DD(I) * M0(I) * ( PD(I) / PD0(I) ) ** ETAM(I);  armington
*august 17 carb tax for trade
* MEQ(I).. M(I)* DD0(I) =E= DD(I) * M0(I) * ( (PD(I)/(PW0(I)*(1+ TCINTENS(I) * CARBRATE)))/ (PD0(I)/PW0(I)) ) ** ETAM(I);
* 3.03 AVERAGE PRICE FACED BY DOMESTIC CONSUMPTION
*
  PEQ(I).. P(I) =E= ( ( DS(I) - CX(I) ) * PD(I) +
                      M(I) * PW0(I) *(1 + TCINTENS(I) * CARBRATE) * ( 1 + SUM(G, TAUM(G,I) ) ) ) /
                    ( DS(I) - CX(I) + M(I) );
*
* 3.04 NET CAPITAL INFLOW
*lingyun add extra items to balance nkieq(original function wrong)
* NKIEQ.. NKI =E= SUM(I, M(I) * PW0(I) ) - SUM(I, CX(I) * PD(I) )- SUM(G, SAM(G,'ROW') )+SUM(G, SAM('ROW',G) );
NKIEQ.. NKI =E= SUM(I, M(I) * PW0(I) ) - SUM(I, CX(I) * PD(I) );
*----------------------------------------------------------------
* 6.2.4 INVESTMENT
*----------------------------------------------------------------
*
* 4.01 INVESTMENT BY SECTOR OF DESTINATION
*
  NEQ(I).. N(I) =E= KS(I) * DEPR;
*
* 4.02 INVESTMENT BY SECTOR OF SOURCE
*
  CNEQ(I).. P(I) * ( 1 + SUM(GS, TAUQX(GS,I) ) ) * CN(I) =E= SUM(J, CCM(I,J) * N(J) );
*
* 4.03 DESIRED CAPITAL STOCK
*
  KSEQ(I).. KS(I) =E= KS0(I) * ( R('CAPIT',I) / R0('CAPIT',I) ) ** ETAI(I);
*
* 4.04 INVESTMENT TAX CREDIT EARNED
*
  ITCEQ(I).. ITC(I) =E= SUM(J, N(I) * CCM(J,I) / ( 1 + SUM(GS, TAUQX(GS,J) ) ) * ITCE(J,I) );
*
*----------------------------------------------------------------
* 6.2.5 LABOR SUPPLY AND MIGRATION
*----------------------------------------------------------------
*
* 5.01 LABOR SUPPLY
*
$ONTEXT
  LSEQ(H).. HW(H) / HH(H) =E= HW0(H) / HH0(H)  * ( ( RA('LABOR') / RA0('LABOR') ) / ( CPI(H) / CPI0(H) ) ) ** ETARA(H)
                                              * ( SUM(GI, PIT(GI,H) ) / SUM(GI, PIT0(GI,H) ) ) ** ETAPIT(H)
                                               * ( SUM(G, TP(H,G) / CPI(H) ) / SUM(G, TP0(H,G) / CPI0(H) ) ) ** ETATP(H);
$OFFTEXT
  LSEQ(H).. HW(H) / HH(H) =E= HW0(H) / HH0(H)
        * ( ( YD(H) / YD0(H) ) / ( CPI(H) / CPI0(H) ) ) ** ETARA(H)     ;
*
* 5.02 MIGRATION
*
$ONTEXT
  POPEQ(H).. HH(H) =E= HH0(H) * NRPG(H)
                       + MI0(H) * ( ( (YD(H)+REGYD(H)) / HH(H) )
                                / ( YD0(H) / HH0(H) ) / ( CPI(H) / CPI0(H) ) ) ** ETAYD(H)
                                * ( ( HN(H) / HH(H) ) / ( HN0(H) / HH0(H) ) ) ** ETAU(H)
                                * ( GSED / GSED0 ) ** ETAED(H)
                       - MO0(H) * ( ( YD0(H) / HH0(H) ) / ( (YD(H)+REGYD(H)) / HH(H) )
                                / ( CPI0(H) / CPI(H) ) ) ** ETAYD(H)
                                * ( ( HN0(H) / HH0(H) ) / ( HN(H) / HH(H) ) ) ** ETAU(H)
                                * ( GSED / GSED0 ) ** ETAED(H);
$OFFTEXT
 POPEQ(H).. HH(H) =E= HH0(H) * NRPG(H)-2.5*0.025*(HN(H)-HN0(H))     ;


*
* 5.03 NUMBER OF NON-WORKING HOUSEHOLDS
*
  ANEQ(H).. HN(H) =E= HH(H) - HW(H);
*
*----------------------------------------------------------------
* 6.2.6 HOUSEHOLD INCOME TAXATION
*----------------------------------------------------------------
*
* 6.01 ADJUSTED GROSS INCOMES
*LINGYUN CHANGE HW TO HH  LINGYUN ADD CAPFOR TO FIX AGIEQ
  AGIEQ(H).. AGI(H) =E= SUM(F, A(H,F) * HH(H) / SUM(H1, A(H1,F) * HH(H1) )
                        * OMEGA(F) * (Y(F) - CAPFOR(F)) * ( 1 - SUM(G, TAUFH(G,F) ) ) ) / HH(H);
*
* 6.02 INCOME TAXES
PITEQ(GI,H).. PIT(GI,H) =E= ( TAXBASE(GI,H) + TAXCVC(GI,H)+( AGI(H) - TAXBM(GI,H)- TAXSD(GI,H)
                              - ( TAXOD(GI,H) + SUM(GI1, ATAX(GI1,GI) * PIT(GI1,H) ) ) * TAXPI(GI,H) )
                                 * MTR(GI,H) )
                            - TAXCRED(GI,H) ;
*
*----------------------------------------------------------------
* 6.2.7 GOVERNMENT
*----------------------------------------------------------------
*
* 7.01 GOVERNMENT TAX INCOMES
*LINGYUN CHANGE PIT(G,H)*HW(H) TO PIT(G,H)*HH(H)
***pb
*add row sources
  YGEQ(G).. Y(G) =E=   SUM((I,J),  TAUQX(G,I) * P(I) * REG1(I,J) * VREG1(I,J) * AD(I,J) * DS(J) )
                     + SUM(I,      TAUM(G,I) * M(I) * PW0(I) )
                     + SUM(I,      TAUQX(G,I) * CH(I) * P(I) )
                     + SUM(I,      TAUQX(G,I) * CN(I) * P(I) )
                     + SUM((G1,I), TAUQX(G,I) * CG(I,G1) * P(I) )
                     + SUM((F,I),  TAUFX(G,F,I) * RA(F) * R(F,I)  * FD(F,I) )
                     + SUM((F,G1), TAUFX(G,F,G1) * RA(F) * R(F,G1) * FD(F,G1) )
                     + SUM(F,      TAUFH(G,F) * Y(F) )
                     + SUM(H,      PIT(G,H) * HH(H) )
                     + SUM(H,      TAUH(G,H) * HH(H) )
                     - SUM((I,F),  FITC(F,G) * ITC(I))
                     - SUM(H,LUMP(H,G));
*                      + SAM(G,'INVES')+ SAM(G,'ROW');
*
* 7.015 GOVERNMENT TRANSFERS
*
*~KA estimate GSP June08
  YGEQ2(G).. Y2(G) =E=   SUM((I,J),  TAUQX(G,I) * P(I) * REG1(I,J) *
    VREG1(I,J) * AD(I,J) * DS(J) )
                       + SUM(I,      TAUM(G,I) * M(I) * PW0(I) )
                       + SUM(I,      TAUQX(G,I) * CH(I) * P(I) )
                       + SUM(I,      TAUQX(G,I) * CN(I) * P(I) )
                 ;
***pb
*
*
*
* 7.02 ENDOGENOUS GOVERNMENT CONSUMPTION
* Gov't income is Net transfers to gov; less net transfers to HH;
* less all exogenous payments to and from outsiders and investment;
* plus income from taxation.
*
*
  CGNEQ(I,GN).. P(I) * ( 1 + SUM(GS, TAUQX(GS,I) ) ) * CG(I,GN)
                    =E= AG(I,GN) * REG18(I,GN) * ( SUM(G, IGT(GN,G) - IGT(G,GN) ) - SUM(H, TP(H,GN) * HN(H) * TPC(H,GN) )
                        - S0(GN) + Y(GN) );
*
* 7.03 ENDOGENOUS GOVERNMENT FACTOR RENTALS
***pb as in 7.02
*
  GFNEQ(F,GN).. FD(F,GN) * R(F,GN) * RA(F)
                    =E= AG(F,GN) * REG18(F,GN) * ( SUM(G, IGT(GN,G) - IGT(G,GN) ) - SUM(H, TP(H,GN) * HN(H) * TPC(H,GN) )
                        - S0(GN) + Y(GN) );
*
* 7.04 EXOGENOUS GOVERNMENT CONSUMPTION
*
  CGXEQ(I,GX).. P(I) * ( 1 + SUM(GS, TAUQX(GS,I) ) ) * CG(I,GX) =E= P0(I) * ( 1 + SUM(GS, TAUQ(GS,I)  ) ) * CG0(I,GX);
*
* 7.05 EXOGENOUS GOVERNMENT FACTOR RENTALS
*
  GFXEQ(F,GX).. FD(F,GX) * R(F,GX) * RA(F) =E= FD0(F,GX) * R0(F,GX) * RA0(F);
*
* 7.06 DISTRIBUTION OF TAX REVENUES TO SPENDING DESTINATIONS
*
  TDEQ(G,GT)$(IGTD(G,GT) EQ 1).. IGT(G,GT) =E= TAXS(G,GT) * Y(GT);
*
***pb special case fo ctreg
*7.065  DISTRIBUTION OF ALL REVENUES TO SPENDING DESTINATIONS CTREG
  TDEQ2(G,GT)$(IGTD(G,GT) EQ 5).. IGT(G,GT) =E= TAXS(G,GT) * (Y(GT)+ IGT('CTREG','CGENF'));
***
*
* 7.07 DISTRIBUTION FROM SOURCES OF TRANSFER PAYMENTS
*
  TPGTEQ(GW,G1)$(IGTD(GW,G1) EQ 4).. IGT(GW,G1) =E= IGT0(GW,G1) + SUM(H, HN(H)  * TP(H,GW)  * TPC(H,GW) )
                                                                - SUM(H, HN0(H) * TP0(H,GW) * TPC(H,GW) );
*
* 7.08 BALANCE OF GENERAL FUND SPREAD EVENLY AMONGST GENERAL FUND UNITS
*original
$ontext
  GFBALEQ(GC).. IGT(GC,'CGENF') =E= ( Y('CGENF') + SUM(G, IGT('CGENF',G) ) - SUM(GL, IGT(GL,'CGENF') ) - S0('CGENF') )
                                     * SAM(GC,'CGENF') / SUM(GC1, SAM(GC1,'CGENF') );
$offtext
***pb  transfer to creg of 2.4 treated like local expenditure
*
  GFBALEQ(GC).. IGT(GC,'CGENF') =E= ( Y('CGENF') + SUM(G, IGT('CGENF',G) ) - SUM(GL, IGT(GL,'CGENF') ) - S0('CGENF')
                                     - IGT('ctreg','CGENF' ) )
                                     * SAM(GC,'CGENF') / SUM(GC1, SAM(GC1,'CGENF') );
* 7.09 GOVERNMENT SAVINGS
*
*
*
  GSEQ(G).. S(G) =E= Y(G) + SUM(G1, IGT(G,G1) - IGT(G1,G) ) - SUM(H, TP(H,G) * HN(H) * TPC(H,G) )
                          - SUM(I, CG(I,G) * P(I) * ( 1 + SUM(GS, TAUQX(GS,I) ) ) )
                          - SUM(F, FD(F,G) * R(F,G) * RA(F) * ( 1 + SUM(GF, TAUFX(GF,F,G) ) ) );
*
* 7.10 PROPOSITION 98 TRANSFER FOR EDUCATION -- TEST 2
*
* PROP98.. IGT('LSK14','CGENF')
*            =E=  IGT0('LSK14','CGENF') * ADA
*               * ( SUM(H, Y(H)  + SUM(G, TP(H,G)  * HN(H)  * TPC(H,G) ) ) / SUM(H, HH(H)  ) )
*               / ( SUM(H, Y0(H) + SUM(G, TP0(H,G) * HN0(H) * TPC(H,G) ) ) / SUM(H, HH0(H) ) );
*
* 7.11 PROPOSITION 98 TRANSFER FOR EDUCATION -- TEST 3
*
  PROP98.. IGT('LSK14','CGENF')
             =E= IGT0('LSK14','CGENF') * ADA
             * ( ( Y('CGENF')  + SUM(G, IGT('CGENF',G)  ) ) / SUM(H, HH(H)  ) )
             / ( ( Y0('CGENF') + SUM(G, IGT0('CGENF',G) ) ) / SUM(H, HH0(H) ) );
*
*
* 7.12 PUBLIC EDUCATION SPENDING
*
  GSEDEQ.. GSED =E= SUM(GED, SUM(G, IGT(GED,G) ) );
*
*----------------------------------------------------------------
* 6.2.8 MODEL CLOSURE
*----------------------------------------------------------------
*
* 8.01 ARTIFICIAL OBJECTIVE FUNCTION -- TOTAL STATE PERSONAL INCOMES
*
   SPIEQ.. SPI =E= SUM(H, ( Y(H) + SUM(G, TP(H,G) * HN(H) * TPC(H,G) ) ) / CPI(H) );
*
* 8.02 LABOR MARKET EQUILIBRIUM
*
  LMEQ.. SUM(H, HW(H) ) =E= SUM(Z, FD('LABOR',Z) ) * JOBCOR;
*
* 8.03 CAPITAL MARKETS EQUILIBRIUM
*
  KMEQ(I).. KS(I) =E= FD('CAPIT',I);
*
* 8.04 GOODS AND SERVICES MARKETS EQUILIBRIUM
*
  GMEQ(I).. DS(I) =E= DD(I) + CX(I) - M(I);
*
* 8.05 DOMESTIC DEMAND DEFINITION
*
  DDEQ(I).. DD(I) =E= V(I) + CH(I) + SUM(G, CG(I,G) ) + CN(I);
*
*8.06 LINGYUN MAKE FREE VARIABLE POSITIVE
*FVPOWER(CSK)..OB =E= FV('CSK14')**2;
*
*----------------------------------------------------------------
* 6.29 MODEL CLOSURE USING FIXED VALUES (COMPUTATIONALLY MORE EFFICIENT THAN EQUATIONS)
*----------------------------------------------------------------
*
* 9.01 FIX PIT FOR NON INCOME TAX UNITS TO ZERO
*
  PIT.FX(G,H)$(NOT GI(G)) = 0;
*
* 9.02 FIX INTER GOVERNMENTAL TRANSFERS TO ZERO IF NOT IN ORIGINAL SAM
*
  IGT.FX(G,G1)$(NOT IGTD(G,G1)) = 0;
*
* 9.03 FIX EXOGENOUS INTERGOVERNMENTAL TRANSFERS
*
  IGT.FX(G,G1)$(IGTD(G,G1) EQ 2) = IGT0(G,G1);
*
* 9.04 FIX GOVERNMENT DEMAND FOR GOODS AND SERVICES TO ZERO IF NOT IN ORIGINAL DATA
*
  CG.FX(I,G)$(NOT SAM(I,G) ) = 0;
*
* 9.05 FIX GOVERNMENT DEMAND FOR FACTORS TO ZERO IF NOT IN ORIGINAL DATA
*
  FD.FX(F,G)$(NOT SAM(F,G) ) = 0;
*
* 9.06 FIX INTER SECTORAL WAGE DIFFERENTIALS
*
  R.FX('LABOR',Z) = R0('LABOR',Z);
*
* 9.07 FIX GOVERNMENT RENTAL RATE FOR CAPITAL TO INITIAL LEVEL
*
  R.FX('CAPIT',G) = R0('CAPIT',G);
*
* 9.08 FIX ECONOMY WIDE SCALAR FOR CAPITAL
*
  RA.FX('CAPIT') = RA0('CAPIT');
*
* 9.09 FIX EXOGENOUS TRANSFER PAYMENT LEVELS
*
  TP.FX(H,GW) = TP0(H,GW);
*
* 9.10 FIX TRANSFER PAYMENTS TO ZERO IF NOT IN ORIGINAL DATA
*
  TP.FX(H,G)$(NOT TP0(H,G)) = 0;
*
*----------------------------------------------------------------
* 7. SOLVE AND OUTPUT PREPARATION
*----------------------------------------------------------------
* 7.1 MODEL FORMULATION
*----------------------------------------------------------------
*
  MODEL SCENARIO /ALL/;
*SCENARIO.optfile=1 ;
*
*----------------------------------------------------------------
* 7.2 SAVING INITIAL VALUES FOR VARIABLES
*----------------------------------------------------------------
$BATINCLUDE ScenOut2003.gms ORDSCEN('BASE')
*----------------------------------------------------------------
* 7.3 POLICY EXPERIMENT LOOP
*----------------------------------------------------------------
* We have M equations in M unknowns, so feasible region is a single point in M-space.
* Thus it does not matter if we maximize or minimize the objective function.
 SOLVE SCENARIO MINIMIZING SPI USING NLP;
*
*
* SAVE SOLUTION VALUES FOR BASE SOLUTION (SHOULD MATCH INITIAL DATA)
*
$BATINCLUDE ScenOut2003.gms ORDSCEN('B_A_U')
$batinclude diagnostics03.gms


*Scenario SCEN1
*    Reset all
$BATINCLUDE Reg03.gms 0 0 0 0
if { ORDSCEN('SCEN1') > 3,
    SOLVE SCENARIO MINIMIZING SPI USING NLP;
};
*etam('mtlfab') = etam('mtlfab')/4 ;
*CARBRATE =0.000;
*
* Scenario for 2020 @ 20%
*
$BATINCLUDE REG03.GMS 1 ORDVAL('OILGAS') ORDVAL('oilref')  -1.0 ;

*$BATINCLUDE REG.gms 1 ORDVAL('AGRIC') ORDVAL('DISTEL')           0.336        ;
*$BATINCLUDE REG.gms 1 ORDVAL('CONNON') ORDVAL('DISTEL')          1.288        ;
*$BATINCLUDE REG.gms 1 ORDVAL('MTLFAB') ORDVAL('DISTEL')          1.920        ;
*$BATINCLUDE REG.gms 1 ORDVAL('OILGAS') ORDVAL('DISTEL')         -1.544        ;

*REGM('oilgas') = -1.544;
*

 SOLVE SCENARIO MINIMIZING SPI USING NLP;
$BATINCLUDE ScenOut2003.gms ORDSCEN('SCEN1')


*Scenario SCEN2
*    Reset all
*$BATINCLUDE Reg.gms 0 0 0 0
*if { ORDSCEN('SCEN2') > 3,
*    SOLVE SCENARIO MINIMIZING SPI USING NLP;
*};
* Set price of carbon here:
*CARBRATE =0.010;
*
* Scenario for 2020 @ 33%
*
*$BATINCLUDE REG.gms 1 ORDVAL('AGRIC') ORDVAL('DISTEL')           0.336        ;
*$BATINCLUDE REG.gms 1 ORDVAL('CONNON') ORDVAL('DISTEL')          2.311        ;
*$BATINCLUDE REG.gms 1 ORDVAL('MTLFAB') ORDVAL('DISTEL')          4.428        ;
*$BATINCLUDE REG.gms 1 ORDVAL('OILGAS') ORDVAL('DISTEL')         -2.305        ;


*REGM('oilgas') = -2.305-0.913;
*
* SOLVE SCENARIO MINIMIZING SPI USING NLP;
*$BATINCLUDE ScenOut.gms ORDSCEN('SCEN2')

*
*
*----------------------------------------------------------------
* 7.4 PUT RESULTS INTO OUTPUT FILE
*----------------------------------------------------------------
*
  PUT 'SCENARIO                        ';
  LOOP(T, PUT T.TL);
  PUT /;
*
  PUT 'MODEL                           ';
  LOOP(T, LOOP(MS$(R2('M-STAT',T) EQ ORD(MS) ), PUT MS.TE(MS) ) );
  PUT /;
*
  PUT 'SOLVER                          ';
  LOOP(T, LOOP(SS$(R2('S-STAT',T) EQ ORD(SS) ), PUT SS.TE(SS) ) );
  PUT /;
*
  LOOP(R1H, PUT R1H.TE(R1H);
            LOOP(T, PUT R1(R1H,T) );
            PUT / );
*
  LOOP((R3H,Z)$SUM(T, R3(R3H,Z,T)), PUT R3H.TE(R3H), Z.TL;
                                    LOOP(T, PUT R3(R3H,Z,T) );
                                    PUT / );
*
  LOOP(I, PUT I.TL; PUT /;
          LOOP(R4LH, PUT R4H.TE(R4LH) I.TL;
*          LOOP(R4LH, PUT R4H.TE(R4LH)'    ';
                    LOOP(T, PUT R4(R4LH,I,T) );
                    PUT / ));
*
*EOM 4/17/08 added r4new to facilitate formatting for excel export
*
parameter R4new(I,R4LH,T);
R4new(I,R4LH,T) = R4(R4LH,I,t);
*
*EOM 4/17/08 utilizing GDX facility for exporting results to excel
*These five lines dump the reporting parameters into 4 separate sheets
*within the workbook in the project directory.
$ONTEXT
execute_unload 'SCENARIO.gdx' R4new R3 R2 R1
execute 'gdxxrw SCENARIO.gdx output=SCENARIO.xls par=R4new rng=R4!'
execute 'gdxxrw SCENARIO.gdx output=SCENARIO.xls par=R3 rng=R3!'
execute 'gdxxrw SCENARIO.gdx output=SCENARIO.xls par=R2 rng=R2!'
execute 'gdxxrw SCENARIO.gdx output=SCENARIO.xls par=R1 rng=R1!'
$OFFTEXT
***Peter Berck adds to show SAM2020, May 14, 2009
execute_unload 'SAM2020.gdx' SAM
execute 'gdxxrw SAM2020.gdx output=SAM2020.xls par=SAM rng=sam!'

***To show AD, i.e., DOMESTIC INPUT OUTPUT COEFFICIENTS
Display AD, S.L;






























